<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl local func plesk"
  xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl		="http://exslt.org/common"
  xmlns:sw			="http://www.swsoft.com/xsl/cp"
  xmlns:plesk		="http://www.swsoft.com/xsl/cp/plesk"
  xmlns:env			="http://www.swsoft.com/xsl/cp/env"  
  xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:func		="http://exslt.org/functions"
	xmlns:vzapackagem	="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:math		="http://exslt.org/math"
	xmlns:vz			="http://www.swsoft.com/xsl/cp/vz"
	xmlns:vt			="http://www.swsoft.com/xsl/cp/vt"
	xmlns:ve			="http://www.swsoft.com/xsl/cp/ve"
	xmlns:cred    ="http://www.swsoft.com/xsl/cp/cred"
>

  <sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vz/apps.xsl"/>
	<sw:include href="/lib/vza/vzapackagem.xsl"/>

	<func:function name="plesk:check-autoinstall">
		<xsl:param name="ve-eid" select="sw:ve-eid()"/>
		<xsl:variable name="master-hn-eid"	select="sw:master-eid()"/>
		<xsl:variable name="hn-eid"	select="sw:ve-parent($ve-eid)"/>
		<xsl:variable name="env"	select="env:get-env($ve-eid)/env"/>
		<xsl:variable name="env-config" select="$env/virtual_config"/>
		<xsl:variable name="hostname" select="$env-config/hostname"/>
		<xsl:variable name="ip" select="$env-config/address/ip[1]"/>

		<xsl:variable name="env-platform" select=" ve:ve2platform($env)"/>
		<xsl:variable name="platform-is-linux"  select="vt:is-platform-linux($env-platform)"/>
		<xsl:variable name="ve-platform" select="sw:if($platform-is-linux,'linux','windows')"/>

		<xsl:variable name="autoinstall-allowed"
			select="exsl:node-set($config/vzcpcon/defines/install-plesk/autoinstall-allowed)"/>
		<xsl:variable name="check-autoinstall-result-rtf">
      <xsl:choose>
        <xsl:when test="not($autoinstall-allowed)">
          <!-- no autoinstall section	-->
          <problem>
          	<cred>
          		<xsl:value-of select="cred:check-hw('vzcp.hn.view',$master-hn-eid)"/>
          	</cred>
						<reason>
							<sw:text>The "autoinstall-allowed" section is not defined in vzcpcon.conf.</sw:text>
						</reason>
						<solution>
							<sw:text>Define the "autoinstall-allowed" section in vzcpcon.conf and restart the vzcp service.</sw:text>
						</solution>
            <log>
              Description: plesk cannot be automatically installed into VE EID: <xsl:value-of select="$ve-eid"/>.
              Reason: in vzcpcon.conf not defined "autoinstall-allowed" section.
              Solution: define in vzcp.conf section "autoinstall-allowed" and restart vzcp.          	
            </log>
          </problem>
        </xsl:when>
        <xsl:when test="$autoinstall-allowed">
          <!-- prepare node with current base name and version -->
          <!-- ve-templates - templates, already installed on VE -->
          <xsl:variable name="ve-templates" 
            select="vzapackagem:list4env($ve-eid, 'all', false())/packet/data/vzapackagem/packages/package"/>
            
          <xsl:variable name="ve-oses" select="$ve-templates[vzapackagem:is-os(.)]"/>
          <xsl:variable name="base-set" select="$ve-oses[not(version) or version= math:max($ve-oses/version)]"/>

          <xsl:variable name="new-vzapackagem" select="sw:is-ez-package($base-set/name)"/>

          <!-- prepare invalid-qos: described in config but vsp don't have such qos 
               where live-qos - qos from lived VE
                     req-wos -  qos descibed in autoinstall config
          -->
          <xsl:variable name="live-qos" select="$env-config/qos"/>
          <xsl:variable name="req-qos"
            select="exsl:node-set($config/vzcpcon/defines/install-plesk/autoinstall-allowed/ubcs[@platform = $ve-platform]/qos)"/>

          <xsl:variable name="invalid-qos-rtf">
          	<xsl:choose>
          		<xsl:when test="$platform-is-linux">
								<xsl:copy-of select="$req-qos[local:get-invalid-qos-for-linux($live-qos,id,hard,soft)]"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="$req-qos[local:get-invalid-qos-for-windows($live-qos,id,limit)]"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="invalid-qos" select="exsl:node-set($invalid-qos-rtf)/qos"/>
					
          <!-- prepare req-config: find corresponding config for autoinstall
               by VE  base-set name and version.
               First try get base-set with defined version, if failed, try get
               from config default section (only by name)						 
          -->
          <xsl:variable name="pre-req-config-rtf">
            <xsl:variable name="req-conf-with-version">
              <xsl:copy-of
                select="$config/vzcpcon/defines/install-plesk/autoinstall-allowed/base-set[(name = $base-set/name) and (version = $base-set/version)]"
              />
            </xsl:variable>
            <xsl:variable name="req-conf-without-version">
              <xsl:copy-of
                select="$config/vzcpcon/defines/install-plesk/autoinstall-allowed/base-set[(name = $base-set/name) and (not(version) or (version = ''))]"
              />
            </xsl:variable>
            <xsl:choose>
              <xsl:when test="$req-conf-with-version != ''">
                <xsl:copy-of select="$req-conf-with-version"/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:copy-of select="$req-conf-without-version"/>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:variable>

          <!-- hw-templates - all templates installed on HW node -->
          <xsl:variable name="hw-templates"
            select="vz:load-hw-apps($base-set, env:make-platform-ref($env-config/../parent_eid), 'all',cred:check-env('vzcp.env.manage.properties.application',$ve-eid))"/>

          <xsl:variable name="ez-plesk-detect-name" select="'.plesk8'"/>
          <xsl:variable name="ez-plesk-detect-auto" select="($pre-req-config-rtf = '') and ($ez-plesk-detect-name != '') and $new-vzapackagem and $platform-is-linux"/>

          <xsl:variable name="win-plesk-detect-name" select="string($hw-templates[sw:re-test(name,'^plesk([_-]*)8([0-9_.-]*)$')]/name)"/>
          <xsl:variable name="win-plesk-detect-auto" select="($pre-req-config-rtf = '') and ($win-plesk-detect-name != '') and not($platform-is-linux)"/>

          <xsl:variable name="req-config-rtf">
            <xsl:choose>
              <xsl:when test="$ez-plesk-detect-auto">
                <base-set>
                  <name>
                    <xsl:value-of select="$base-set/name"/>
                  </name>
                  <package>
                    <name>
                      <xsl:value-of select="$ez-plesk-detect-name"/>
                    </name>
                  </package>
                </base-set>
              </xsl:when>
              <xsl:when test="$win-plesk-detect-auto">
                <base-set>
                  <name>
                    <xsl:value-of select="$base-set/name"/>
                  </name>
                  <package>
                    <name>
                      <xsl:value-of select="$win-plesk-detect-name"/>
                    </name>
                  </package>
                </base-set>
              </xsl:when>              
              <xsl:otherwise>
                <xsl:copy-of select="exsl:node-set($pre-req-config-rtf)"/>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:variable>
          <xsl:variable name="req-config" select="exsl:node-set($req-config-rtf)"/>
          
          <!-- If req-config required templates, and such templates already 
               installed in VE, excliude this from install 
               package-for-install carry out only needed templates. 
          -->
          <xsl:variable name="package-for-install-rtf">
            <xsl:copy-of
              select="$req-config/base-set/package[not(local:getInstalledTmpl(name,version,$ve-templates,$hw-templates))]"
            />
          </xsl:variable>
          <xsl:variable name="package-for-install" select="exsl:node-set($package-for-install-rtf)"/>

					<!-- reformat package-for-install to vzapkg view -->          
          <xsl:variable name="apps">
            <xsl:for-each select="$package-for-install/package">
              <xsl:variable name="name" select="name"/>
              <xsl:variable name="version" select="version"/>
							<xsl:variable name="last-version"  select="math:max($hw-templates[name=$name]/version)"/>
							<xsl:choose>
								<xsl:when test="$new-vzapackagem">
									<!-- ez template has no version -->
									<xsl:copy-of select="$hw-templates[name = $name]"/>
								</xsl:when>
								<xsl:when test="($version = '') and (number($last-version) &gt;= 0)">
									<!-- last version required -->
									<xsl:copy-of select="$hw-templates[(name = $name) and (version = $last-version)]"/>
								</xsl:when>
								<xsl:when test="number($version) &gt;= 0">
									<!-- concrete version required -->
									<xsl:copy-of select="$hw-templates[(name = $name) and (version = $version)]"/>									
								</xsl:when>
								<xsl:otherwise>
									<!-- no version required -->
									<xsl:copy-of select="$hw-templates[name = $name]"/>
								</xsl:otherwise>
							</xsl:choose>									
            </xsl:for-each>
          </xsl:variable>

          <!-- prepare invalid-tmpl: templates described in corresponding config section but
               not presenet on hw node -->
          <xsl:variable name="invalid-tmpl"
            select="exsl:node-set($req-config/base-set/package[not(local:getValidTmpl($hw-templates,name,version))])"/>

					<xsl:choose>
						<xsl:when test="$req-config/base-set and ($package-for-install = '' or not($package-for-install))">
              <xsl:variable name="problem-template-list-text">
                <xsl:for-each select="$req-config/base-set/package">
                  <xsl:choose>
                    <xsl:when test="version != ''">
                      <sw:text>
                        <xsl:with-param name="name" 		select="name"/>
                        <xsl:with-param name="version"	select="version"/>
                        name: %{name}, version: %{version} <br/>
                      </sw:text>
                    </xsl:when>
                    <xsl:otherwise>
                      <sw:text>
                        <xsl:with-param name="name"	select="name"/>
                        name: %{name}, version: not defined, using latest <br/>
                      </sw:text>
                    </xsl:otherwise>
                  </xsl:choose>
                </xsl:for-each>
              </xsl:variable>
              <xsl:variable name="problem-template-list-log">
                <xsl:for-each select="$req-config/base-set/package">
                  name: <xsl:value-of select="name"/>, version: <xsl:value-of select="sw:if(version != '',version,'not defined, used last')"/>
                </xsl:for-each>
              </xsl:variable>						
              <problem>
		          	<cred>
    		      		<xsl:value-of select="cred:check-hw('vzcp.hn.view',$master-hn-eid)"/>
        		  	</cred>              
								<reason>
									<sw:text>All the requested templates are already added to the Container, but Plesk cannot be detected.</sw:text>
								</reason>
								<solution>
									<sw:text>
										<xsl:with-param name="template-list" select="$problem-template-list-text"/>
										Check that the following templates really describe Plesk: <br/> %{template-list}
									</sw:text>
								</solution>
                <log>
                  Description: plesk cannot be automatically installed into VE EID: <xsl:value-of select="$ve-eid"/>.
                  Reason: all requested template(s) already installed in VE, but plesk can't be detected.
                  Solution: check that next templates realy describe plesk - <xsl:value-of select="$problem-template-list-log"/>
                </log>
              </problem>
            </xsl:when>
            <xsl:when test="(count($invalid-tmpl) &gt; 0) and not($ez-plesk-detect-auto) and not($win-plesk-detect-auto)">
              <!-- error : specified invalid template/version in config -->
              <xsl:variable name="invalid-template-list-text">
                <xsl:for-each select="$invalid-tmpl">
                  <xsl:choose>
                    <xsl:when test="version != ''">
                      <sw:text>
                        <xsl:with-param name="name" 		select="name"/>
                        <xsl:with-param name="version"	select="version"/>
                        name %{name}, version: %{version} <br/>
                      </sw:text>
                    </xsl:when>
                    <xsl:otherwise>
                      <sw:text>
                        <xsl:with-param name="name"	select="name"/>
                        name %{name}, version: any <br/>
                      </sw:text>
                    </xsl:otherwise>
                  </xsl:choose>
                </xsl:for-each>
              </xsl:variable>
              <xsl:variable name="invalid-template-list-log">
                <xsl:for-each select="$invalid-tmpl">
                  name: <xsl:value-of select="name"/>, version: <xsl:value-of select="sw:if(version != '',version,'any')"/>
                </xsl:for-each>
              </xsl:variable>						
              <problem>
								<cred>
                	<xsl:value-of select="cred:check-hw('vzcp.template',$hn-eid)"/>
                </cred>
								<reason>
									<sw:text>Some templates are listed as required in vzcpcon.conf, but they are not installed on the Hardware Node.</sw:text>
								</reason>
								<solution>
									<sw:text>
										<xsl:with-param name="os-name" select="$base-set/name"/>
										<xsl:with-param name="template-list" select="$invalid-template-list-text"/>                      
										Install the following templates on the Hardware Node for the %{os-name} OS:  <br/> %{template-list}
									</sw:text>
								</solution>
                <log>
                  Description: plesk cannot be automatically installed into VE EID: <xsl:value-of select="$ve-eid"/>.
                  Reason: in vzcpcon.conf required application(s) which is not installed on hardware node.
                  Solution: for OS <xsl:value-of select="$base-set/name"/> install on hardware node next application(s) - <xsl:value-of select="$invalid-template-list-log"/>
                </log>
              </problem>
						</xsl:when>
            <xsl:when test="(count($invalid-tmpl) &gt; 0) and ($ez-plesk-detect-auto or $win-plesk-detect-auto)">
              <!-- error : plesk name autodetect failed (for EZ only) -->
              <xsl:variable name="invalid-template-list-text">
                <xsl:for-each select="$invalid-tmpl">
                  <sw:text>
                    <xsl:with-param name="name"	select="name"/>
                    name: %{name} <br/>
                  </sw:text>
                </xsl:for-each>
              </xsl:variable>
              <xsl:variable name="invalid-template-list-log">
                <xsl:for-each select="$invalid-tmpl">
                  name: <xsl:value-of select="name"/> 
                </xsl:for-each>
              </xsl:variable>						
              <problem>
								<cred>
                	<xsl:value-of select="cred:check-hw('vzcp.template',$hn-eid)"/>
                </cred>              
								<reason>
									<sw:text>
										<xsl:with-param name="os-name" select="$base-set/name"/>
										<xsl:with-param name="template-list" select="$invalid-template-list-text"/>
										The Container is based on the %{os-name} OS, for which no Plesk template is installed on the Hardware Node: <br/> %{template-list}
									</sw:text>
								</reason>
								<solution>
									<sw:text>
										Install the required templates on the Hardware Node.
									</sw:text>
								</solution>
                <log>
                  Description: plesk cannot be automatically installed into VE EID: <xsl:value-of select="$ve-eid"/>.
                  Reason: VE has OS <xsl:value-of select="$base-set/name"/>, but on Hardware Node for such OS not installed Plesk application(s): <xsl:value-of select="$invalid-template-list-log"/>
                  Solution: install required application(s) on Hardware Node.
                </log>
              </problem>
						</xsl:when>
						<xsl:when test="not($req-config) or ($req-config = '')">
							<!-- error: for current OS not found autoinstaller section  -->
              <problem>
								<cred>
									<xsl:value-of select="cred:check-hw('vzcp.hn.view',$master-hn-eid)"/>
								</cred>              
								<reason>
									<sw:text>
										The Plesk autoinstall is not configured for the current OS.
									</sw:text>
								</reason>
								<solution>
									<sw:text>
										<xsl:with-param name="os-name" select="$base-set/name"/>
										<xsl:with-param name="os-version" select="$base-set/version"/>                    
											Configure the Plesk autoinstall for the %{os-name} OS (version %{os-version}) in vzcpcon.conf.
									</sw:text>
								</solution>
                <log>
                  Description: plesk cannot be automatically installed into VE EID: <xsl:value-of select="$ve-eid"/>.
                  Reason: autoinstaller not configured for current OS.
                  Solution: in vzcpcon.conf configure autoinstaller for OS <xsl:value-of select="$base-set/name"/> (version <xsl:value-of select="$base-set/version"/>)
                </log>
              </problem>
						</xsl:when>
						<xsl:when test="not($hostname) or ($hostname = '')">
							<!-- empty hostname -->
              <problem>
								<cred>
									<xsl:value-of select="cred:check-env('vzcp.env.manage.properties.preferences',$ve-eid)"/>
								</cred>              
								<reason>
									<sw:text>
										The Container hostname is not specified.
									</sw:text>
								</reason>
								<solution>
									<sw:text>
										Set the Container hostname.
									</sw:text>
								</solution>
                <log>
                  Description: plesk cannot be automatically installed into VE EID: <xsl:value-of select="$ve-eid"/>.
                  Reason: hostname for VE not specified.
                  Solution: set hostname for VE.
                </log>
              </problem>							
						</xsl:when>
						<xsl:when test="not($ip) or ($ip = '')">
							<!-- empty ip address -->
              <problem>
								<cred>
									<xsl:value-of select="cred:check-env('vzcp.env.manage.properties.preferences',$ve-eid)"/>
								</cred>              
								<reason>
									<sw:text>
										The Container IP address is not specified.
									</sw:text>
								</reason>
								<solution>
									<sw:text>
										Set the Container IP address.
									</sw:text>
								</solution>
                <log>
                  Description: plesk cannot be automatically installed into VE EID: <xsl:value-of select="$ve-eid"/>.
                  Reason: ip address for VE not specified.
                  Solution: set ip address for VE.
                </log>
              </problem>							
						</xsl:when>						
						<xsl:when test="count($invalid-qos) &gt; 0">
							<!-- resource shortage -->
              <xsl:variable name="qos-info-text">
	              <xsl:for-each select="$invalid-qos">
	              	<xsl:if test="hard">
		              	<sw:text>
		              		<xsl:with-param name="qos-name" select="id"/>
		              		<xsl:with-param name="req-hard" select="hard"/>
		              		<xsl:with-param name="cur-value" select="$live-qos[id = current()/id]/hard"/>
											name: %{qos-name}, hard limit required: %{req-hard}, current value: %{cur-value} <br/>
										</sw:text>
									</xsl:if>	
	              	<xsl:if test="soft">
		              	<sw:text>
		              		<xsl:with-param name="qos-name" select="id"/>
		              		<xsl:with-param name="req-soft" select="soft"/>
		              		<xsl:with-param name="cur-value" select="$live-qos[id = current()/id]/soft"/>
											name: %{qos-name}, soft limit required: %{req-soft}, current value: %{cur-value} <br/>
										</sw:text>
									</xsl:if>
	              	<xsl:if test="limit">
		              	<sw:text>
		              		<xsl:with-param name="qos-name" select="id"/>
		              		<xsl:with-param name="limit" select="limit"/>
		              		<xsl:with-param name="cur-value" select="$live-qos[id = current()/id]/hard"/>
											name: %{qos-name}, value required: %{limit}, current value: %{cur-value} <br/>
										</sw:text>
									</xsl:if>									
                </xsl:for-each>
              </xsl:variable>
              <xsl:variable name="qos-info-log">
	              <xsl:for-each select="$invalid-qos">
									name: <xsl:value-of select="id"/> 
									<xsl:if test="hard">
										requirment hard limit : <xsl:value-of select="hard"/>, current value <xsl:value-of select="$live-qos[id = current()/id]/hard"/>
									</xsl:if>
									<xsl:if test="soft">
										requirment soft limit : <xsl:value-of select="soft"/>, current value <xsl:value-of select="$live-qos[id =  current()/id]/soft"/>
									</xsl:if>
									<xsl:if test="limit">
										requirment value : <xsl:value-of select="limit"/>, current value <xsl:value-of select="$live-qos[id =  current()/id]/hard"/>
									</xsl:if>									
                </xsl:for-each>
              </xsl:variable>              
              <problem>
								<cred>
									<xsl:value-of select="cred:check-env('vzcp.env.manage.resources',$ve-eid)"/>
								</cred>              
								<reason>
									<sw:text>
										The Container does not have enough resources.
									</sw:text>
								</reason>
								<solution>
									<sw:text>
										<xsl:with-param name="qos-info" select="$qos-info-text"/>
										Adjust the following resources as described.<br/>
										 %{qos-info}
									</sw:text>
								</solution>
                <log>
                  Description: plesk cannot be automatically installed into VE EID: <xsl:value-of select="$ve-eid"/>.
                  Reason: VE has not enough resources.
                  Solution: correct next resources as described - <xsl:value-of select="$qos-info-log"/>
                </log>
              </problem>							
						</xsl:when>
						<xsl:otherwise>
							<!-- plesk install allowed, saved apps in answer -->
							<xsl:copy-of select="exsl:node-set($apps)"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<!-- /autoinstall allowed -->
			</xsl:choose>
		</xsl:variable>
		<func:result select="exsl:node-set($check-autoinstall-result-rtf)"/>
	</func:function>


	<func:function name="local:getInstalledTmpl">
		<xsl:param name="name"/>
		<xsl:param name="version"/>
		<xsl:param name="ve-templates"/>
		<xsl:param name="hw-templates"/>
		<xsl:choose>
			<xsl:when test="sw:is-ez-package($name)">
				<func:result select="boolean($ve-templates[$name = name])"/>
			</xsl:when>
			<xsl:when test="($version = '') or not($version)">
				<!-- In config not specified version, must be install last.
						 Get from hw-templates last version number and check it on vzenv -->
				<xsl:variable name="last-version"
					select="math:max($hw-templates[name = $name]/version)"/>
				<func:result
					select="boolean($ve-templates[$name = name and $last-version = version])"/>
			</xsl:when>
			<xsl:otherwise>
				<!--  version present in requested config, test for this version -->
				<func:result select="boolean($ve-templates[$name = name and $version = version])"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>


	<func:function name="local:get-invalid-qos-for-linux">
		<xsl:param name="live-qos"/>
		<xsl:param name="id"/>
		<xsl:param name="hard" select="0"/>
		<xsl:param name="soft" select="0"/>
		<func:result
			select="exsl:node-set($live-qos)[id = $id and not((hard &gt;= $hard and soft &gt;= $soft) or ((not(hard) or hard = 0) and soft &gt;= $soft) or ((not(soft) or soft = 0) and hard &gt;= $hard) or ((not(soft) or soft = 0) and (not(hard) or hard = 0)))]"
		/>
	</func:function>


	<func:function name="local:get-invalid-qos-for-windows">
		<xsl:param name="live-qos"/>
		<xsl:param name="id"/>
		<xsl:param name="limit" select="0"/>
		<func:result
			select="exsl:node-set($live-qos)[id = $id and not( (hard &gt;= $limit) or (not(hard) or (hard = 0)) )]"
		/>
	</func:function>


	<func:function name="local:getValidTmpl">
		<xsl:param name="tmpl-config"/>
		<xsl:param name="name"/>
		<xsl:param name="version"/>
		<xsl:choose>
			<xsl:when test="sw:is-ez-package($name)">
				<func:result select="exsl:node-set($tmpl-config)[name = $name ]"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result
					select="exsl:node-set($tmpl-config)[name = $name and  (version = $version or string($version) = '')]"
				/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>


</xsl:stylesheet>
