<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl local func plesk"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:plesk	="http://www.swsoft.com/xsl/cp/plesk"
  xmlns:env		="http://www.swsoft.com/xsl/cp/env"  
  xmlns:local	="http://www.swsoft.com/xsl/cp/local"
  xmlns:ve		="http://www.swsoft.com/xsl/cp/ve"
	xmlns:func	="http://exslt.org/functions"
	xmlns:vzenv	="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:authm ="http://www.swsoft.com/xsl/cp/authm"
 >

	<sw:include href="/lib/swa/authm.xsl"/>
 	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/psa_auth.xsl"/>
	<sw:include href="/lib/vt/ve-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-offline.xsl"/>
	
  <!-- 
       Detect presence of plesk by check plesk account in VE 
       Try to do vzauth -t pleskadmin and analize errors
    -->
  <func:function name="local:plesk-user-present">
    <xsl:param name="eid"/>
		<!-- authm/authenticate check that name is 'admin', only in such case call 
					vzauth with paramater "-t pleskadmin "
		-->
		<xsl:variable name="name-base64"      select="sw:base64-encode('admin')"/>
    <xsl:variable name="domain-base64"    select="sw:base64-encode($eid)"/>
		<xsl:variable name="all-realms"				select="authm:list-realms()"/> 
    <xsl:variable name="ve-realm-id"      select="$all-realms/realm[type = 1000]/id"/>
		
		<xsl:variable name="req">
			<packet>
				<target>authm</target>
        <xsl:copy-of select="sw:hn-dst($eid)"/>
				<data>
					<authm>
						<authenticate>
							<name><xsl:value-of select="$name-base64"/>cHNhYWRt</name>
							<domain><xsl:value-of select="$domain-base64"/></domain>
							<realm><xsl:value-of select="$ve-realm-id"/></realm>
							<password/>
						</authenticate>
					</authm>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>
		<xsl:variable name="error-auth" select="sw:xchg($req)/packet/data/authm/error/code"/>
    <func:result select="sw:if($error-auth  = '3205',false(),true())"/>
  </func:function>
  

  <!-- Detect precense of plesk, installed by template OR by rpm
	Return:
		<installed>
			<by-template>
				<name>XXX</name>
				<version>YYY</version>
			</by-template>
					OR
			<by-eztemplate>
				<name>XXX</name>
			</by-eztemplate>			
					OR
			<by-wintemplate>
				<name>XXX</name>
			</by-wintemplate>			
					OR					
			<by-manual/>
		<not-installed/>
		<unknown/>
  -->
  <func:function name="plesk:detect-plesk">
    <xsl:param name="eid"/>
    
    <xsl:variable name="env-info" select="env:eid2info($eid)"/>
    <xsl:variable name="env"			select="env:get-env($eid)/env"/>
    <xsl:variable name="plesk-name-in-std-templates" select="'psa-'"/>
    <xsl:variable name="plesk-name-in-ez-templates" select="'plesk'"/>
    <xsl:variable name="plesk-name-in-win-templates" select="'plesk'"/>

		<xsl:variable name="installed-templates" select="ve:get-env-templates($env)"/>
		<xsl:variable name="plesk-old-tmpl"	select="$installed-templates/template[not(sw:is-ez-package(name)) and starts-with(name,$plesk-name-in-std-templates)]"/>
		<xsl:variable name="plesk-ez-tmpl"	select="$installed-templates/template[sw:is-ez-package(name) and contains(name,$plesk-name-in-ez-templates)]"/>
		<xsl:variable name="plesk-win-tmpl"	select="$installed-templates/template[$env-info/windows and contains(name,$plesk-name-in-win-templates)]"/>

    <xsl:variable name="vzve-plesk-status">
			<xsl:choose>
      	<!-- try detect in templates -->
				<xsl:when test="$plesk-old-tmpl/name">
					<installed>
						<by-template>
							<name>
								<xsl:value-of select="$plesk-old-tmpl/name"/>
							</name>
							<version>
								<xsl:value-of select="$plesk-old-tmpl/version"/>
							</version>							
						</by-template>
					</installed>
				</xsl:when>
				<xsl:when test="$plesk-ez-tmpl/name">
					<installed>
						<by-eztemplate>
							<name>
								<xsl:value-of select="$plesk-ez-tmpl/name"/>
							</name>
						</by-eztemplate>
					</installed>
				</xsl:when>
				<xsl:when test="$plesk-win-tmpl/name">
					<installed>
						<by-wintemplate>
							<name>
								<xsl:value-of select="$plesk-win-tmpl/name"/>
							</name>
						</by-wintemplate>
					</installed>
				</xsl:when>
				<!-- try detect manual install in linux -->
				<xsl:when test="$env-info/linux">
					<xsl:choose>
						<xsl:when test="local:plesk-user-present($eid)">
							<installed>
								<by-manual/>
							</installed>
						</xsl:when>
						<xsl:otherwise>
							<not-installed/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<!-- try detect manual install on windows -->
				<xsl:when test="$env-info/windows">
					<xsl:variable name="plesk-by-registry-detect" select="exsl:node-set(plesk:check-plesk-registry($eid))"/>
          <xsl:choose>
            <xsl:when test="$plesk-by-registry-detect/error">
            	<!-- can not detect, ve not running -->
							<unknown/>
            </xsl:when>
            <xsl:when test="$plesk-by-registry-detect/plesk-root-dir != ''">
							<installed>
								<by-manual/>
							</installed>
            </xsl:when>
            <xsl:when test="not($plesk-by-registry-detect/plesk-root-dir != '')">
            	<not-installed/>
            </xsl:when>
            <xsl:otherwise>
							<unknown/>
            </xsl:otherwise>
          </xsl:choose>
				</xsl:when>
      </xsl:choose>
    </xsl:variable>
    <func:result select="exsl:node-set($vzve-plesk-status)"/>
  </func:function>

	<func:function name="plesk:is-allowed">
		<xsl:param name="veid" select="sw:ve-eid()"/>
		<!-- Check offline service configuration -->
		<xsl:variable name="service" select="'vzpp-plesk'"/>
		<xsl:variable name="service-status" select="exsl:node-set(vzenv:ve-offline-status($service,$veid))"/>
		<xsl:variable name="ve-run" select="ve:context-state() = $env-state/running"/>		
		<xsl:variable name="service-login-result-rtf">
			<xsl:choose>
				<xsl:when test="($service-status/service-global-present = 0) and not($ve-run)">
					<!-- no offline service on HW node, vzenv not run -->
					<xsl:value-of select="1"/>
				</xsl:when>
				<xsl:when test="($service-status/service-present = 0) and not($ve-run)">
					<!-- offline service disable for VE, vzenv not run -->
					<xsl:value-of select="2"/>
				</xsl:when>
				<xsl:when test="not($service-status/ip-address != '')">
					<!-- VE no has IP address -->
					<xsl:value-of select="3"/>  
				</xsl:when>
				<xsl:otherwise>
					<!-- login allowed -->
					<xsl:value-of select="0"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="not(boolean(number($service-login-result-rtf)))"/>
	</func:function>

</xsl:stylesheet>
