<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred func reg32"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:str		="http://exslt.org/strings"
	xmlns:func	="http://exslt.org/functions"
	xmlns:reg32	="http://www.swsoft.com/xsl/cp/reg32"
	xmlns:plesk	="http://www.swsoft.com/xsl/cp/plesk"
  xmlns:env		="http://www.swsoft.com/xsl/cp/env"
  xmlns:ve		="http://www.swsoft.com/xsl/cp/ve"
	xmlns:process ="http://www.swsoft.com/xsl/cp/process"
	xmlns:vt    ="http://www.swsoft.com/xsl/cp/vt"
>
 	<sw:include href="/lib/vt/env-core.xsl"/>
 	<sw:include href="/lib/vt/core.xsl"/> 	
	<sw:include href="/lib/progm.xsl"/>
	<sw:include href="/lib/reg32.xsl"/>

	<!-- plesk login -->
	<xsl:template name="plesk:make-login-plesk">
		<xsl:param name="psa_active_lang" select="$plesk-lang-id"/>
		<xsl:choose>
			<xsl:when test="cred:is-demo-mode()">
				<!-- Handle demo mode -->
				<xsl:if test="sw:sesput('plesk-state','demo')"/>
			</xsl:when>
			<xsl:when test="cred:check-env('vzcp.env.manage.services.plesk_control_panel',sw:ve-eid())">
				<xsl:variable name="psa-setup" select="plesk:getPsaSetup()"/>
				<xsl:variable name="remote-ip" select="$request/http_request/env/parameter[name = 'REMOTE_ADDR']/value"/>
				<xsl:variable name="sesson-ip" select="sw:if($psa-setup/mode/remote-ip = 'yes',$remote-ip,$sveip)"/>
				<xsl:variable name="exec-args">
					<argv>
						<xsl:value-of select="sw:base64-encode(plesk:get-path-to-plesk-util('vzcp_auth'))"/>
					</argv>
					<argv>
						<xsl:value-of select="sw:base64-encode('login')"/>
					</argv>
					<argv>
						<xsl:value-of select="sw:base64-encode($ticketid)"/>
					</argv>
					<argv>
						<xsl:value-of select="sw:base64-encode($sesson-ip)"/>
					</argv>
					<argv>
						<xsl:value-of select="sw:base64-encode(string($psa_active_lang))"/>
					</argv>
					<stdio>
						<output/>
						<error/>
					</stdio>
				</xsl:variable>
				<xsl:variable name="try-plesk-login" select="process:exec($exec-args,sw:ve-eid())"/>
				<xsl:variable name="login-plesk">
					<xsl:choose>
						<xsl:when test="not($try-plesk-login/process/error)">
							<xsl:value-of select="1"/>
							<xsl:if test="sw:sesput('login-plesk',1)"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="0"/>
							<xsl:if test="sw:sesput('login-plesk',0)"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="$login-plesk = 1">
						<!-- get current  plesk skin name and locale-->
						<xsl:variable name="psa-locale-mode" select="$psa-setup/mode/locale"/>
						<xsl:variable name="psa-setup-real"
							select="sw:node-set(sw:base64-decode($try-plesk-login/process/output))/settings"/>
						<xsl:variable name="skin-obj"
							select="$all-skins[@id = $activeMode]/skin[plesk-skin-id = $psa-setup-real/skin]"/>
						<xsl:variable name="lang-obj-rtf">
							<xsl:choose>
								<xsl:when test="$psa-locale-mode = 'new'">
									<xsl:copy-of select="$all-langs[plesk-locale-id = $psa-setup-real/locale]"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="$all-langs[plesk-lang-id = $psa-setup-real/lang]"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="lang-obj" select="exsl:node-set($lang-obj-rtf)"/>
						<xsl:variable name="modeRTF">
							<id>
								<xsl:value-of select="$activeMode"/>
							</id>
							<xsl:if test="$skin-obj">
								<skin>
									<xsl:value-of select="$skin-obj/id"/>
								</skin>
							</xsl:if>
							<xsl:if test="$lang-obj">
								<lang>
									<xsl:value-of select="$lang-obj/language/id"/>
								</lang>
								<psa-locale-mode>
									<xsl:value-of select="$psa-locale-mode"/>
								</psa-locale-mode>
							</xsl:if>
						</xsl:variable>

						<!-- store mode in session -->
						<xsl:if test="sw:sesput($sessionModeParam, $modeRTF)"/>

						<xsl:value-of select="sw:sesput('psa-version',normalize-space($psa-setup/version/raw))"/>
						<xsl:value-of
							select="sw:sesput('psa-version-detail',normalize-space($psa-setup/version/detail))"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="sw:sesput('psa-version','')"/>
						<xsl:value-of select="sw:sesput('psa-version-detail','')"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- update component only in old version of plesk -->
				<xsl:if
					test="plesk:check-plesk-version-for('update-component',normalize-space($psa-setup/version/detail))">
					<xsl:call-template name="plesk:update-plesk-component"/>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<!-- plesk login NOT allowed -->
				<xsl:if test="sw:sesput('plesk-state','deny')"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="plesk:make-logout-plesk">
		<xsl:variable name="login-plesk" select="sw:sesget('login-plesk')"/>
		<xsl:choose>
			<xsl:when test="$login-plesk = 1">
				<xsl:variable name="exec-arg">
					<argv>
						<xsl:value-of select="sw:base64-encode(plesk:get-path-to-plesk-util('vzcp_auth'))"/>
					</argv>
					<argv>
						<xsl:value-of select="sw:base64-encode('logout')"/>
					</argv>
					<argv>
						<xsl:value-of select="sw:base64-encode($ticketid)"/>
					</argv>
					<stdio>
						<output/>
						<error/>
					</stdio>
				</xsl:variable>
				<xsl:copy-of select="process:exec($exec-arg,sw:ve-eid())"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<func:function name="plesk:getPsaSetup">
		<xsl:variable name="exec-arg">
			<argv>
				<xsl:value-of select="sw:base64-encode(plesk:get-path-to-plesk-util('vzcp_auth'))"/>
			</argv>
			<argv>
				<xsl:value-of select="sw:base64-encode('lang_list')"/>
			</argv>
			<xsl:if test="$request/http_request/env/parameter[name = 'SERVER_NAME']/value">
				<argv>
					<xsl:value-of
						select="sw:base64-encode($request/http_request/env/parameter[name = 'SERVER_NAME']/value)"
					/>
				</argv>
			</xsl:if>
			<stdio>
				<output/>
				<error/>
			</stdio>
		</xsl:variable>
		<xsl:variable name="psa-setup-request" select="process:exec($exec-arg,sw:ve-eid())"/>
		<!-- handle error -->
		<xsl:choose>
			<xsl:when test="not($psa-setup-request/process/error) and not($psa-setup-request/process/output = '')">
				<xsl:variable name="psa-setup-raw"
					select="sw:node-set(sw:base64-decode($psa-setup-request/process/output))/psa_setup"/>
				<xsl:variable name="psa-version" select="$psa-setup-raw/version"/>
				<xsl:variable name="psa-version-detail"
					select="number(str:split($psa-version,' ')[position() = last()])"/>

				<xsl:variable name="psa-locale-mode"
					select="sw:if(plesk:check-plesk-version-for('new-locale',$psa-version-detail),'new','old')"/>
				<xsl:variable name="psa-remote-ip"
					select="sw:if(plesk:check-plesk-version-for('remote-ip',$psa-version-detail),'yes','no')"/>

				<xsl:variable name="psa-setup-rtf">
					<default>
						<skin>
							<xsl:value-of select="$psa-setup-raw/default/skin"/>
						</skin>
						<lang>
							<xsl:value-of
								select="sw:if($psa-locale-mode = 'new',$psa-setup-raw/default/locale,$psa-setup-raw/default/lang)"
							/>
						</lang>
					</default>
					<admin>
						<xsl:choose>
							<xsl:when test="$psa-setup-raw/default/admin">
								<lang>
									<xsl:value-of
										select="sw:if($psa-locale-mode = 'new',$psa-setup-raw/default/admin/locale,$psa-setup-raw/default/admin/lang)"
									/>
								</lang>
								<skin>
									<xsl:value-of select="$psa-setup-raw/default/admin/skin"/>
								</skin>
							</xsl:when>
							<xsl:otherwise>
								<lang>
									<xsl:value-of
										select="sw:if($psa-locale-mode = 'new',$psa-setup-raw/default/locale,$psa-setup-raw/default/lang)"
									/>
								</lang>
								<skin>
									<xsl:value-of select="$psa-setup-raw/default/skin"/>
								</skin>
							</xsl:otherwise>
						</xsl:choose>
					</admin>
					<languages>
						<xsl:choose>
							<xsl:when test="$psa-locale-mode = 'old'">
								<xsl:copy-of select="$psa-setup-raw/languages/language"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:for-each select="$psa-setup-raw/locales/locale">
									<language>
										<xsl:copy-of select="./*"/>
									</language>
								</xsl:for-each>
							</xsl:otherwise>
						</xsl:choose>
					</languages>
					<mode>
						<remote-ip>
							<xsl:value-of select="$psa-remote-ip"/>
						</remote-ip>
						<locale>
							<xsl:value-of select="$psa-locale-mode"/>
						</locale>
					</mode>
					<version>
						<raw>
							<xsl:value-of select="$psa-version"/>
						</raw>
						<detail>
							<xsl:value-of select="$psa-version-detail"/>
						</detail>
					</version>
				</xsl:variable>
				<xsl:variable name="psa-setup" select="exsl:node-set($psa-setup-rtf)"/>
				<func:result select="$psa-setup"/>
			</xsl:when>

			<xsl:otherwise>
				<!-- error get psa setup, return empty node -->
				<func:result select="/.."/>
			</xsl:otherwise>

		</xsl:choose>
	</func:function>

	<xsl:template name="plesk:update-plesk-component">
		<xsl:variable name="exec-arg">
			<argv>
				<xsl:value-of select="sw:base64-encode(plesk:get-path-to-plesk-util('cu_plesk_component'))"/>
			</argv>
			<stdio>
				<output/>
			</stdio>
		</xsl:variable>
		<xsl:copy-of select="process:exec($exec-arg,sw:ve-eid())"/>
	</xsl:template>

	<xsl:template name="plesk:get-plesk-password">
		<xsl:variable name="exec-arg">
			<argv>
				<xsl:value-of select="sw:base64-encode('/bin/cat')"/>
			</argv>
			<argv>
				<xsl:value-of select="sw:base64-encode('/etc/psa/.psa.shadow')"/>
			</argv>
			<stdio>
				<error/>
				<output/>
			</stdio>
		</xsl:variable>
		<xsl:copy-of select="process:exec($exec-arg,sw:ve-eid())"/>
	</xsl:template>

	<func:function name="plesk:get-path-to-plesk-util">
		<xsl:param name="name"/>
		<xsl:param name="eid" select="sw:ve-eid()"/>		

		<xsl:variable name="env-info" select="env:eid2info($eid)"/>

		<xsl:variable name="path">
			<xsl:choose>
				<xsl:when test="$env-info/linux">
					<xsl:choose>
						<xsl:when test="$name = 'vzcp_auth'">
							<xsl:value-of select="'/usr/local/psa/admin/sbin/vzcp_auth'"/>
						</xsl:when>
						<xsl:when test="$name = 'cu_plesk_component'">
							<xsl:value-of select="'/usr/local/psa/bin/cu_plesk_component.sh'"/>
						</xsl:when>
						<xsl:when test="$name = 'cu_plesk_get_menu'">
							<xsl:value-of select="'/usr/local/psa/bin/cu_plesk_get_menu.sh'"/>
						</xsl:when>
						<xsl:when test="$name = 'ch_admin_passwd'">
							<xsl:value-of select="'/usr/local/psa/admin/bin/ch_admin_passwd'"/>
						</xsl:when>
						<xsl:when test="$name = 'pleskctl'">
							<xsl:value-of select="'/usr/local/psa/admin/sbin/pleskctl'"/>
						</xsl:when>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="$env-info/windows">
					<xsl:variable name="plesk-root-dir-old" select="sw:sesgetstr('plesk-root-dir')"/>
					<xsl:variable name="plesk-root-dir-new">
						<xsl:choose>
							<xsl:when test="not($plesk-root-dir-old != '')">
								<!-- no root dir, calc it -->
								<xsl:variable name="plesk-by-registry-detect"
									select="exsl:node-set(plesk:check-plesk-registry($eid))"/>
								<xsl:value-of
									select="sw:if($plesk-by-registry-detect/plesk-root-dir,string($plesk-by-registry-detect/plesk-root-dir),'NOTSUPPORTED')"
								/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$plesk-root-dir-old"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<!-- cache it -->
					<xsl:if test="sw:sesputstr('plesk-root-dir',$plesk-root-dir-new)"/>
					<xsl:choose>
						<xsl:when test="$name = 'vzcp_auth'">
							<xsl:value-of select="concat($plesk-root-dir-new,'admin/bin/vzcp_auth.exe')"/>
						</xsl:when>
						<xsl:when test="$name = 'cu_plesk_component'">
							<xsl:value-of select="'NOTSUPPORTED'"/>
						</xsl:when>
						<xsl:when test="$name = 'cu_plesk_get_menu'">
							<xsl:value-of select="concat($plesk-root-dir-new,'admin/bin/cu_plesk_get_menu.exe')"/>
						</xsl:when>
						<xsl:when test="$name = 'ch_admin_passwd'">
							<xsl:value-of select="'NOTSUPPORTED'"/>
						</xsl:when>
						<xsl:when test="$name = 'pleskctl'">
							<xsl:value-of select="concat($plesk-root-dir-new,'admin/bin/pleskctl.exe')"/>
						</xsl:when>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="'NOTSUPPORTED'"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="$path"/>
	</func:function>

	<!-- 
       Win32 only.
       Detect presence of plesk by check registry:
				'Software\PLESK\PSA Config\Config' /v PRODUCT_ROOT_D
					 and 
				'Software\Wow6432Node\PLESK\PSA Config\Config' /v PRODUCT_ROOT_D
    -->
	<func:function name="plesk:check-plesk-registry">
		<xsl:param name="eid" select="sw:ve-eid()"/>
		<xsl:variable name="reg-path-32" select="'Software\PLESK\PSA Config\Config'"/>
		<xsl:variable name="reg-body">
			<plesk-root-dir>
				<pattern>PRODUCT_ROOT_D</pattern>
			</plesk-root-dir>
		</xsl:variable>
		<xsl:variable name="reg-32-rc" select="reg32:get($reg-path-32,$reg-body,$eid)"/>
		<xsl:choose>
			<xsl:when test="$reg-32-rc/error">
				<func:result>
					<error/>
				</func:result>
			</xsl:when>
			<xsl:when test="$reg-32-rc/output">
				<xsl:variable name="plesk-root-dir" select="$reg-32-rc/output/plesk-root-dir"/>
				<xsl:choose>
					<xsl:when test="not($plesk-root-dir != '')">
						<!-- need call here 64 bit version -->
						<xsl:variable name="reg-path-64"
							select="'Software\Wow6432Node\PLESK\PSA Config\Config'"/>
						<xsl:variable name="reg-64-rc" select="reg32:get($reg-path-64,$reg-body,$eid)"/>
						<xsl:choose>
							<xsl:when test="$reg-64-rc/error">
								<error/>
							</xsl:when>
							<xsl:when test="$reg-64-rc/output">
								<func:result>
									<plesk-root-dir>
										<xsl:value-of select="$reg-64-rc/output/plesk-root-dir"/>
									</plesk-root-dir>
								</func:result>
							</xsl:when>
							<xsl:otherwise>
								<func:result>
									<error/>
								</func:result>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<func:result>
							<plesk-root-dir>
								<xsl:value-of select="$plesk-root-dir"/>
							</plesk-root-dir>
						</func:result>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<func:result>
					<error/>
				</func:result>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<func:function name="plesk:check-plesk-version-for">
		<xsl:param name="category"/>
		<xsl:param name="cur-version"/>

		<xsl:variable name="eid" select="sw:ve-eid()"/>
		<xsl:variable name="env" select="env:get-env($eid)/env"/>
		<xsl:variable name="env-platform" select="ve:ve2platform($env)"/>

		<xsl:variable name="category-defined" select="sw:if($config/vzcpcon/psa-feature-set/*[name() = $category],true(),false())"/>
		<xsl:variable name="start-version-raw"
			select="$config/vzcpcon/psa-feature-set/*[name() = $category]/version[vt:compare-platforms($env-platform,@platform)]/start"/>
		<xsl:variable name="end-version-raw"
			select="$config/vzcpcon/psa-feature-set/*[name() = $category]/version[vt:compare-platforms($env-platform,@platform)]/end"/>

		<!-- normalize start and end version -->
		<xsl:variable name="start-version">
			<xsl:choose>
				<xsl:when test="not($start-version-raw != '')">
					<xsl:value-of select="0"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$start-version-raw"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="end-version">
			<xsl:choose>
				<xsl:when test="not($end-version-raw != '')">
					<xsl:value-of select="9999999999999999.99"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$end-version-raw"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="sw:if($category-defined and (number($cur-version) &gt;= number($start-version)) and (number($cur-version) &lt;= number($end-version)),true(),false())"/>
	</func:function>

	<xsl:template name="plesk:pleskctl-repair">
		<xsl:param name="actions"/>
		<xsl:variable name="exec-arg">
			<argv><xsl:value-of select="sw:base64-encode(plesk:get-path-to-plesk-util('pleskctl'))"/></argv>
			<argv><xsl:value-of select="sw:base64-encode('--repair')"/></argv>
			<xsl:for-each select="$actions">
				<argv><xsl:value-of select="sw:base64-encode(.)"/></argv>							
			</xsl:for-each>
			<stdio>
				<output/>
				<error/>
			</stdio>
		</xsl:variable>
		<xsl:variable name="try-pleskctl" select="process:exec($exec-arg,sw:ve-eid())"/>
		<xsl:variable name="result-pleskctl-rtf">
			<xsl:choose>
				<xsl:when test="not($try-pleskctl/process/error)">
					<xsl:copy-of select="sw:node-set(sw:base64-decode($try-pleskctl/process/output))"/>
				</xsl:when>
				<xsl:otherwise>
					<!-- error, fail exec "pleskctl repair" -->
					<xsl:copy-of select="$try-pleskctl/process/error"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:copy-of select="exsl:node-set($result-pleskctl-rtf)"/>
	</xsl:template>


	<xsl:template name="plesk:pleskctl-status">
		<xsl:variable name="exec-arg">
			<argv><xsl:value-of select="sw:base64-encode(plesk:get-path-to-plesk-util('pleskctl'))"/></argv>
			<argv><xsl:value-of select="sw:base64-encode('--status')"/></argv>
			<stdio>
				<output/>
				<error/>
			</stdio>
		</xsl:variable>
		<xsl:variable name="try-pleskctl" select="process:exec($exec-arg,sw:ve-eid())"/>
		<xsl:variable name="result-pleskctl-rtf">
			<xsl:choose>
				<xsl:when test="not($try-pleskctl/process/error)">
					<xsl:copy-of select="sw:node-set(sw:base64-decode($try-pleskctl/process/output))"/>
				</xsl:when>
				<xsl:otherwise>
					<!-- error, fail exec "pleskctl status" -->
					<xsl:copy-of select="$try-pleskctl/process/error"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:copy-of select="exsl:node-set($result-pleskctl-rtf)"/>
	</xsl:template>


</xsl:stylesheet>
