<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl env cred"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:error	="http://www.swsoft.com/xsl/cp/error"
	xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"
>

	<sw:include href="/lib/vt/env-core.xsl"/>

	<xsl:output method="xml"/>

	<xsl:variable name="eid" select="sw:ve-eid()"/>

	<!-- check permissions to process request -->
	<xsl:variable name="cr-plesk-panel"
		select="cred:check-env('vzcp.env.manage.services.plesk_control_panel',$eid)"/>

	<xsl:template match="/">
		<packet>
			<!-- check premissions before execute request -->
			<target>progm</target>
			<xsl:copy-of select="sw:hn-dst($eid)"/>

			<xsl:choose>
				<xsl:when test="$request/http_request/post/parameter[name = 'LoginTicketDemo']">
					<!-- it's demo, on screen hidden demo ticket -->
					<xsl:if test="cred:detail-check-env('vzcp.env.manage.services.plesk_control_panel',$eid)"/>
					<packet/>
				</xsl:when>				
				<xsl:when test="not($cr-plesk-panel)">
					<!-- no cred for plesk panel, no need any data -->
				</xsl:when>
				<xsl:otherwise>
					<!-- creds present, update vzenv info -->
					<xsl:variable name="env" select="env:get-env($eid)/env"/>
					<!-- update plesk info status -->
					<xsl:for-each select="$env/virtual_config">
						<!-- update  veinfo -->
						<xsl:value-of select="sw:sesput('hostname', string(hostname))"/>
						<xsl:value-of select="sw:sesput('templates', template)"/>
						<xsl:value-of select="sw:sesput('ip',ip)"/>
					</xsl:for-each>
					<xsl:if test="/http_request/post/parameter[name = '_submit']/value">
						<!-- set plesk password -->
						<xsl:choose>
							<xsl:when
								test="not(string(/http_request/post/parameter[name = 'passwd']/value)) or not(string(/http_request/post/parameter[name = 'retype']/value))">
								<!-- check password presence -->
								<xsl:if test="error:put(sw:text('You cannot specify an empty password.'))"/>
								<cookie>
									<show-form/>
								</cookie>
							</xsl:when>

							<xsl:when
								test="/http_request/post/parameter[name = 'passwd']/value != /http_request/post/parameter[name = 'retype']/value">
								<!-- check passwords match -->
								<xsl:if test="error:put(sw:text('The passwords do not match.'))"/>
								<cookie>
									<show-form/>
								</cookie>
							</xsl:when>

							<xsl:when
								test="string-length(/http_request/post/parameter[name = 'passwd']/value) &lt; 5">
								<!-- check passwords length -->
								<xsl:if test="error:put(sw:text('The password should be at least 5 characters long.'))"/>
								<cookie>
									<show-form/>
								</cookie>
							</xsl:when>

							<xsl:when test="/http_request/post/parameter[name = 'passwd']/value">
								<xsl:if test="error:is-empty()">
									<xsl:if
										test="cred:detail-check-env('vzcp.env.manage.services.plesk_control_panel',$eid)"
									/>
								</xsl:if>
								<xsl:if test="error:is-empty()">
									<cookie>
										<msg>
											<ok>The password has been successfully changed</ok>
											<error>Failed to change admin password</error>
										</msg>
										<operation>change_admin_psa_password</operation>
									</cookie>
									<data>
										<progm>
											<exec>
												<eid>
													<xsl:value-of select="$eid"/>
												</eid>
												<argv>
													<xsl:value-of
														select="sw:base64-encode('/usr/local/psa/admin/sbin/ch_admin_passwd')"/>
												</argv>
												<envp>
													<xsl:value-of
														select="sw:base64-encode(concat('PSA_PASSWORD=', /http_request/post/parameter[name = 'passwd']/value))"
													/>
												</envp>
												<stdio>
													<error/>
												</stdio>
											</exec>
										</progm>
									</data>
									<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
								</xsl:if>
							</xsl:when>
						</xsl:choose>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</packet>

	</xsl:template>
	<!-- credentials -->
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/cred.xsl"/>

</xsl:stylesheet>
