<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func cred env plesk local"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:func		="http://exslt.org/functions"
	xmlns:env			="http://www.swsoft.com/xsl/cp/env"
	xmlns:cred		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:plesk		="http://www.swsoft.com/xsl/cp/plesk"
	xmlns:vzapackagem	="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:error		="http://www.swsoft.com/xsl/cp/error"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
>

	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vza/vzapackagem.xsl"/>
	<sw:include href="/lib/plesk/core.xsl"/>
	<sw:include href="/lib/plesk/autoinstall.xsl"/>

	<xsl:output method="xml"/>

	<xsl:template name="local:install-plesk">
		<xsl:param name="ve-eid" select="sw:ve-eid()"/>
		<xsl:param name="package-for-install" select="/.."/>		
		
		<xsl:variable name="packet-rtf">
			<xsl:call-template name="vzapackagem:action-packet">
				<xsl:with-param name="command" select="'install'"/>
				<xsl:with-param name="app-id" select="$package-for-install"/>
				<xsl:with-param name="hn-eid" select="sw:ve-parent($ve-eid)"/>
				<xsl:with-param name="target-eid" select="$ve-eid"/>
				<xsl:with-param name="cookie">
					<cookie>
						<msg>
							<sched>
								<sw:text>The Plesk installation has been scheduled.</sw:text>
							</sched>
							<error>
								<sw:text>Failed to install Plesk.</sw:text>
							</error>
						</msg>
						<operation>plesk-install</operation>
					</cookie>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		<xsl:copy-of select="exsl:node-set($packet-rtf)/packet/*"/>
		<xsl:if test="sw:response('lib/opredirect.xsl')"/>
	</xsl:template>


	<xsl:template match="/">
		<xsl:variable name="ve-eid" select="sw:ve-eid()"/>
		<xsl:variable name="plesk-autoinstall-status"	select="plesk:check-autoinstall($ve-eid)"/>		
		<xsl:variable name="vzve-plesk-status" select="plesk:detect-plesk($ve-eid)"/>

			<packet log="on">		
				<xsl:choose>
					<xsl:when test="$vzve-plesk-status/installed">
						<!-- handle case while plesk just installed ,
							 from example:  Install psa in another window -->
						<cookie>
							<xsl:choose>
								<xsl:when test="$layout != 'plesk-integrated'">
									<redirect>
										<xsl:value-of select="concat($baseurl,'/panel/plesk')"/>
									</redirect>
								</xsl:when>
								<xsl:otherwise>
									<redirect>
										<xsl:value-of select="concat($baseurl,'/clients/clients.php3')"/>
									</redirect>
								</xsl:otherwise>
							</xsl:choose>
						</cookie>
						<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
					</xsl:when>
					<xsl:when test="($request/http_request/post/parameter[name = 'install-plesk']/value) and not($plesk-autoinstall-status/problem)">
						<!-- Install required by user and still allowed, double check  -->
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:attribute name="progress">on</xsl:attribute>
								<xsl:call-template name="local:install-plesk">
									<xsl:with-param name="ve-eid" select="$ve-eid"/>
									<xsl:with-param name="package-for-install" select="$plesk-autoinstall-status/*"/> 
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:when test="count($plesk-autoinstall-status/problem) &gt; 0">
						<!-- autoinstall now allowed, put in cookie problem description -->
						<cookie>
							<xsl:copy-of select="$plesk-autoinstall-status"/>
						</cookie>
					</xsl:when>
					<xsl:otherwise>
						<!-- user allowed install plesk, no problem detected. It's first screeen with info text -->
					</xsl:otherwise>
				</xsl:choose>
				<vzcpauth/>
		</packet>

	</xsl:template>

	<!-- System modules -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/common.xsl"/>

</xsl:stylesheet>
