<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:error	="http://www.swsoft.com/xsl/cp/error"
	xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:plesk	="http://www.swsoft.com/xsl/cp/plesk"
	xmlns:process	="http://www.swsoft.com/xsl/cp/process"
>

	<xsl:variable name="admin_pwd"
		select="$request/http_request/post/parameter[name = 'admin_pwd']/value"/>
	<xsl:variable name="admin_pwd_re"
		select="$request/http_request/post/parameter[name = 'admin_pwd_re']/value"/>
	<xsl:variable name="action" select="$request/http_request/post/parameter[name = '_submit']/value"/>
	<xsl:variable name="ve-eid" select="sw:ve-eid()"/>

	<xsl:variable name="cr-plesk-password"
		select="cred:check-env('vzcp.env.manage.services.plesk_control_panel',$ve-eid)"/>

	<xsl:template match="/">
		<packet>
			<xsl:copy-of select="sw:hn-dst($ve-eid)"/>
			<!-- check premissions before execute request -->
			<xsl:if test="$cr-plesk-password">
				<xsl:choose>
					<xsl:when test="not($action != '')">
						<!-- no submit, first form load -->
					</xsl:when>
					<xsl:when test="not($admin_pwd !='')">
						<!-- check password presence -->
						<xsl:value-of
							select="error:put(sw:text('The password was not specified.'),'','admin_pwd')"
						/>
					</xsl:when>

					<xsl:when test="string-length($admin_pwd) &lt; 5">
						<!-- check passwords length -->
						<xsl:if test="error:put(sw:text('The password should be at least 5 characters long.'),'','admin_pwd')"
						/>
					</xsl:when>

					<xsl:when test="$admin_pwd != $admin_pwd_re">
						<!-- check passwords match -->
						<xsl:value-of select="error:put(sw:text('The passwords do not match.'),'','admin_pwd')"/>
						<xsl:value-of select="error:add-control('admin_pwd_re')"/>
					</xsl:when>

					<xsl:otherwise>
						<xsl:if test="error:is-empty()">
							<xsl:if
								test="cred:detail-check-env('vzcp.env.manage.services.plesk_control_panel',$ve-eid)"
							/>
						</xsl:if>
						<xsl:if test="error:is-empty()">
							<xsl:variable name="exec-arg">
								<argv>
									<xsl:value-of
										select="sw:base64-encode(plesk:get-path-to-plesk-util('ch_admin_passwd'))"/>
								</argv>
								<envp>
									<xsl:value-of select="sw:base64-encode(concat('PSA_PASSWORD=', $admin_pwd))"/>
								</envp>
								<stdio>
									<output/>
									<error/>
								</stdio>
							</xsl:variable>
							<xsl:variable name="ret" select="process:exec($exec-arg,$ve-eid)"/>
							<cookie>
								<msg>
									<xsl:choose>
										<xsl:when test="not($ret/process/error)">
											<set-ok>
												<sw:text>The password has been successfully changed.</sw:text>
											</set-ok>
										</xsl:when>
										<xsl:otherwise>
											<set-error>
												<short-desc>
													<sw:text>Failed to change the password of the 'admin' user.</sw:text>
												</short-desc>
												<detail>
													<xsl:value-of select="sw:base64-decode($ret/process/error/message)"/>
												</detail>
											</set-error>
										</xsl:otherwise>
									</xsl:choose>
								</msg>
							</cookie>
							<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
						</xsl:if>
					</xsl:otherwise>

				</xsl:choose>
			</xsl:if>
		</packet>
	</xsl:template>
	<!-- credentials -->

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/progm.xsl"/>
	<sw:include href="/lib/psa_auth.xsl"/>

</xsl:stylesheet>
