<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl local func"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:ui			="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:ve			="http://www.swsoft.com/xsl/cp/ve"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:func		="http://exslt.org/functions"
	xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:voc			="http://www.swsoft.com/xsl/cp/voc"
>

	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-apps.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/screen.xsl"/>
	
	<xsl:variable name="ve-eid" select="sw:ve-eid()"/>
	<xsl:variable name="vestate" select="ve:context-state()"/>

	<xsl:variable name="tips-id">
		<xsl:choose>
			<xsl:when test="$vestate = $env-state/running">07.01.04.03</xsl:when>
			<xsl:otherwise>07.01.04.02</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<xsl:variable name="oper-problem" select="voc:check-operation('vzapackagem','install')"/>
	<xsl:variable name="is-ve-updating" select="vzenv:is-ve-updating($ve-eid)"/>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		<ui:screen title="{sw:text('Install Plesk Control Panel')}" id="03.05.00.00.06">
			<xsl:choose>
				<xsl:when test="$is-ve-updating">
					<!-- ve is already updating, plesk installation just sheduled -->
					<ui:properties>
						<ui:refresh-type>none</ui:refresh-type>
						<ui:width value="fixed"/>
						<ui:description mandatory="yes">
							<sw:text>
								The Plesk installation on your Container has started.<br/>
								You can check the status of the operation in the My Tasks log.<br/>
								After you have verified that the installation is complete, you may start using the Plesk control panel.
							</sw:text>
						</ui:description>
					</ui:properties>
					<ui:content/>
				</xsl:when>
				<xsl:when test="$oper-problem != ''">
					<!-- hadnle wrong state of ve -->
					<ui:properties>
						<ui:refresh-type>none</ui:refresh-type>
						<ui:width value="fixed"/>
					</ui:properties>
					<ui:content>					
						<ui:block>
							<ui:operation-problem>
								<xsl:copy-of select="$oper-problem"/>
								<ui:descr>
									<sw:text>Plesk cannot be automatically installed on your Container.</sw:text>
								</ui:descr>
							</ui:operation-problem>
						</ui:block>
					</ui:content>
				</xsl:when>
				<xsl:when test="count(packet/cookie/problem) &gt; 0">
					<xsl:variable name="plesk-autoinstall-problem" select="packet/cookie/problem"/>
					<!-- plesk can not be autoinstalled into ve. Let's show this problem -->
					<ui:properties>
						<ui:refresh-type>none</ui:refresh-type>
						<ui:width value="fixed"/>
					</ui:properties>
					<ui:content>
						<xsl:choose>
							<xsl:when test="$plesk-autoinstall-problem/cred = 'true'">
								<!-- report detail problem for user with creds  -->
								<ui:block>
									<ui:operation-problem>
										<ui:type>custom</ui:type>
										<ui:descr>
											<sw:text>Plesk cannot be automatically installed on the Container.</sw:text>
										</ui:descr>         
										<ui:reason>
											<xsl:copy-of select="$plesk-autoinstall-problem/reason"/>
										</ui:reason>
										<ui:solution>
											<xsl:copy-of select="$plesk-autoinstall-problem/solution"/>
										</ui:solution>
									</ui:operation-problem>
								</ui:block>
							</xsl:when>
							<xsl:otherwise>
								<!-- report problem for user without cred-->
								<xsl:call-template name="local:plesk-autoinstall-error"/>
							</xsl:otherwise>								
						</xsl:choose>
					</ui:content>
					<!-- report problem in log -->
					<xsl:message>
						<xsl:copy-of select="$plesk-autoinstall-problem/log"/>
					</xsl:message>					
				</xsl:when>
				<xsl:otherwise>
					<!-- autoinstallation allowed -->	
					<xsl:call-template name="local:plesk-autoinstall-screen"/>
				</xsl:otherwise>
			</xsl:choose>
		</ui:screen>
	</xsl:template>
	

	<xsl:template name="local:plesk-autoinstall-screen">
		<ui:properties>
			<ui:refresh-type>none</ui:refresh-type>
			<ui:width value="fixed"/>
			<ui:description mandatory="yes">
				<div style="margin: 10px 0px;">
					<sw:text>
          	To proceed with the Plesk installation, press <b>Install</b>.<br/>
            Mind that the process may take some time. After the installation is complete, you may start working in the Plesk control panel.
          </sw:text>
				</div>
			</ui:description>
		</ui:properties>
		<ui:content>
			<ui:block mode="edit">
				<ui:buttons>
					<ui:button type="ok" tip="{$tips-id}" name="install-plesk" sandclock="true">
						<sw:text>Install</sw:text>
					</ui:button>
				</ui:buttons>
			</ui:block>
		</ui:content>
	</xsl:template>

	<xsl:template name="local:plesk-autoinstall-error">
		<!-- load sample of answer in default case -->
		<xsl:variable name="autoinstall-not-allowed" select="exsl:node-set($config/vzcpcon/defines/install-plesk/autoinstall-not-allowed)"/>
		<ui:block>
			<ui:operation-problem>
				<ui:type>custom</ui:type>
				<xsl:choose>
					<xsl:when test="$autoinstall-not-allowed/problem/description|reason|solution">
						<xsl:for-each select="$autoinstall-not-allowed/problem">
							<ui:descr>
								<sw:text select="description/node()"/>
							</ui:descr>
							<ui:reason>
								<sw:text select="reason/node()"/>
							</ui:reason>					
							<ui:solution>
								<sw:text select="solution/node()"/>
								<xsl:if test="link-url and link-text">&#160;<ui:link href="{link-url}" target="_blank" tip="external_plesk_install">
										<sw:text select="string(link-text)"/>
									</ui:link>.
								</xsl:if>
							</ui:solution>
							<xsl:if test="$autoinstall-not-allowed/manual-install-hint/solution">
								<xsl:for-each select="$autoinstall-not-allowed/manual-install-hint">
									<ui:solution>
										<sw:text select="solution/node()"/>
										<xsl:if test="link-url and link-text">&#160;<ui:link href="{link-url}" target="_blank"
												tip="external_plesk_install">
												<sw:text select="string(link-text)"/>
											</ui:link>.
										</xsl:if>
									</ui:solution>
								</xsl:for-each>
							</xsl:if>					
						</xsl:for-each>
					</xsl:when>
					<xsl:otherwise>
						<!-- no hints in vzcpcon.conf, use hardcoded -->
						<ui:descr>
							<sw:text>Plesk cannot be automatically installed on Container.</sw:text>
						</ui:descr>         
						<ui:reason>
							<sw:text>An internal error has occurred.</sw:text>
						</ui:reason>
						<ui:solution>
							<sw:text>Contact your provider for further information.</sw:text>
						</ui:solution>
					</xsl:otherwise>
				</xsl:choose>
			</ui:operation-problem>
		</ui:block>		
	</xsl:template>


</xsl:stylesheet>
