<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:hwm		="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"
	xmlns:vzenv	="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:plesk	="http://www.swsoft.com/xsl/cp/plesk"
	xmlns:ve		="http://www.swsoft.com/xsl/cp/ve"
	xmlns:env   ="http://www.swsoft.com/xsl/cp/env"
>

	<!-- check permissions to show this page -->

	<xsl:variable name="eid" select="sw:ve-eid()"/>
	<xsl:variable name="cr-plesk-login"
		select="cred:check-env('vzcp.env.manage.services.plesk_control_panel',$eid)"/>

	<xsl:param name="access-denied" select="not($cr-plesk-login)"/>
	<xsl:variable name="vzve-plesk-status" select="sw:sesget('vzve-plesk-status')"/>

	<xsl:variable name="vestate" select="ve:context-state()"/>
	<xsl:variable name="service-status"
		select="exsl:node-set(vzenv:ve-offline-status('vzpp-plesk',sw:ve-eid()))"/>

	<xsl:variable name="env" select="env:get-env($eid)/env"/>
	<xsl:variable name="env-platform" select="ve:ve2platform($env)"/>
         
	<xsl:variable name="login-result">
		<xsl:choose>
			<xsl:when test="$vzve-plesk-status/not-installed">
				<!-- plesk not present -->
				<ui:block>
					<ui:operation-problem>
						<ui:descr>
							<sw:text>You have no Plesk installed into your Container.</sw:text>
						</ui:descr>
					</ui:operation-problem>
				</ui:block>
			</xsl:when>

			<xsl:when test="not($service-status/ip-address != '')">
				<ui:block>
					<ui:operation-problem>
						<ui:reason>
							<sw:text>The Container has no host-routed IP address assigned.</sw:text>
						</ui:reason>
						<ui:solution>
							<xsl:choose>
								<xsl:when test="cred:check-env('vzcp.env.manage.properties.preferences',$eid)">
									<ui:i18n-link href="{$baseurl}/vzdir/infrman/envs/manage?tab=net"
										tip="03.02.01.03.02">
										<_>Please %{aopen}assign an IP address%{aclose} and try again.</_>
									</ui:i18n-link>
								</xsl:when>
								<xsl:otherwise>
									<sw:text>Please assign an IP address and try again.	</sw:text>
								</xsl:otherwise>
							</xsl:choose>
						</ui:solution>
						<ui:descr>
							<sw:text>Unable to manage Plesk.</sw:text>
						</ui:descr>
					</ui:operation-problem>
				</ui:block>
			</xsl:when>

			<xsl:when test="vt:is-platform-windows($env-platform)">
				<xsl:choose>
					<xsl:when test="$vestate != $env-state/running">
						<xsl:variable name="oper-problem" select="voc:check-operation('plesk')"/>
						<ui:block>
							<ui:operation-problem>
								<xsl:copy-of select="$oper-problem"/>
								<ui:descr>
									<sw:text>Unable to manage Plesk.</sw:text>
								</ui:descr>
							</ui:operation-problem>
						</ui:block>
					</xsl:when>
				</xsl:choose>
			</xsl:when>

			<xsl:when
				test="$vzve-plesk-status/installed and ($service-status/service-present != 1) and ($vestate != $env-state/running)">
				<!-- vzenv not controlled by VZPP and VE is down -->
				<xsl:variable name="oper-problem" select="voc:check-operation('plesk')"/>
				<ui:block>
					<ui:operation-problem>
						<xsl:copy-of select="$oper-problem"/>
						<ui:descr>
							<sw:text>Unable to manage Plesk.</sw:text>
						</ui:descr>
					</ui:operation-problem>
				</ui:block>
			</xsl:when>

			<xsl:when
				test="$vzve-plesk-status/installed and	($service-status/service-present != 1) and ($vestate = $env-state/running)">
				<!-- VE is on , not under vzpp control (catch be prev when's)
								 try get pure psa password, store it in session.
								 show error if fail, if all ok - show login form, and password change form -->
				<xsl:variable name="plesk-password-detail-rtf">
					<xsl:call-template name="plesk:get-plesk-password"/>
				</xsl:variable>
				<xsl:variable name="plesk-password-detail"
					select="exsl:node-set($plesk-password-detail-rtf)"/>
				<xsl:choose>
					<xsl:when test="$plesk-password-detail/process/error">
						<!-- system error occured: no such programm, vzenv is down, other -->
						<xsl:variable name="plesk-detail" select="$plesk-password-detail/process/error/message"/>
						<xsl:message>Plesk manage error: can't get password for VE #<xsl:value-of
								select="$eid"/>: <xsl:value-of select="$plesk-detail"/></xsl:message>
						<xsl:variable name="oper-problem-rtf">
							<type>custom</type>
							<ui:reason>
								<sw:text>
									<xsl:with-param name="plesk-detail" select="$plesk-detail"
									/>
											An internal error occurred in Plesk.<br/> %{plesk-detail}
										</sw:text>
							</ui:reason>
							<ui:solution>
								<sw:text>Contact your provider for details</sw:text>
							</ui:solution>
						</xsl:variable>
						<ui:block>
							<ui:operation-problem>
								<xsl:copy-of select="exsl:node-set($oper-problem-rtf)"/>
								<ui:descr>
									<sw:text>Unable to manage Plesk</sw:text>
								</ui:descr>
							</ui:operation-problem>
						</ui:block>
					</xsl:when>

				</xsl:choose>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>


	<xsl:template mode="screen" match="/">
		<ui:screen id="03.05.00.01.04" title="{sw:text('Log in to Plesk Control Panel')}"
			icon="login_to_plesk" bg="plesk">
			<ui:properties>
				<ui:width value="fixed"/>
				<ui:no-default-form/>
			</ui:properties>
			<ui:content>
				<xsl:copy-of select="exsl:node-set($login-result)"/>
			</ui:content>
		</ui:screen>
	</xsl:template>


	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-offline.xsl"/>
	<sw:include href="/lib/vza/hwm.xsl"/>
	<sw:include href="/lib/psa_auth.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/progm.xsl"/>
	<sw:include href="/lib/screen.xsl"/>

</xsl:stylesheet>
