<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred func env"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:func	="http://exslt.org/functions"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:redirect="http://www.swsoft.com/xsl/cp/redirect"
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
	xmlns:vzenv	="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"
	xmlns:plesk	="http://www.swsoft.com/xsl/cp/plesk"
	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"
	xmlns:ve		="http://www.swsoft.com/xsl/cp/ve"
>

	<xsl:variable name="ve-eid" select="sw:ve-eid()"/>

	<!-- check permissions to show this page -->
	<xsl:variable name="cr-plesk-login"
		select="cred:check-env('vzcp.env.manage.services.plesk_control_panel',$ve-eid)"/>

	<xsl:param name="access-denied" select="not($cr-plesk-login)"/>
	<xsl:variable name="vzve-plesk-status" select="plesk:detect-plesk($ve-eid)"/>

	<xsl:variable name="env"    			select="env:get-env($ve-eid)/env"/>
	<xsl:variable name="env-platform" select="ve:ve2platform($env)"/>
	<xsl:variable name="platform-is-linux"  select="vt:is-platform-linux($env-platform)"/>

	<xsl:template match="/">

		<!-- Reset error -->
		<xsl:if test="sw:sesput('ve-error','')"/>

		<!-- Check offline service configuration -->
		<!-- do it, becuase client can load dashboard, change condition from
    			cmd line or from other browser windows , and then click 
          on icon "Login to Plesk" -->

            
		<xsl:variable name="vestate" select="ve:context-state()"/>
		<xsl:variable name="service-status"
			select="exsl:node-set(vzenv:ve-offline-status('vzpp-plesk',$ve-eid))"/>

		<xsl:variable name="login-result">
			<xsl:choose>
				<xsl:when test="$vzve-plesk-status/unknown">
					<xsl:variable name="error">
						<!-- can't detect plesk (windows and vps stopped and plesk not in tmpl) -->
						<sw:text>
              Cannot determine if Plesk is installed into your Container. A possible reason is that the Container is not running.
            </sw:text>
						<br/>
						<sw:text>Unable to log in to Plesk.</sw:text>
					</xsl:variable>
					<xsl:if test="sw:sesput('vps-error',$error)"/>
				</xsl:when>
				<xsl:when test="$vzve-plesk-status/not-installed">
					<xsl:variable name="error">
						<!-- plesk not present -->
						<sw:text>
								You have no Plesk installed into your Container.
							</sw:text>
						<br/>
						<sw:text>Unable to log in to Plesk.</sw:text>
					</xsl:variable>
					<xsl:if test="sw:sesput('ve-error',$error)"/>
				</xsl:when>
				<xsl:when test="not($service-status/ip-address != '')">
					<xsl:variable name="error">
						<!-- no IP  -->
						<sw:text>
								The Container has no host-routed IP address assigned.
							</sw:text>
						<br/>
						<sw:text>Unable to log in to Plesk.</sw:text>
					</xsl:variable>
					<xsl:if test="sw:sesput('ve-error',$error)"/>
				</xsl:when>
				<xsl:when
					test="$vzve-plesk-status/installed and ($service-status/service-present != 1) and ($vestate != $env-state/running)">
					<xsl:variable name="error">
						<!-- not running VE  and VE not hav offline management  -->
						<sw:text>
								The Container is not running and its offline management is disabled.
							</sw:text>
						<br/>
						<sw:text>Unable to log in to Plesk.</sw:text>
					</xsl:variable>
					<xsl:if test="sw:sesput('ve-error',$error)"/>
				</xsl:when>

				<xsl:when
					test="$platform-is-linux and $vzve-plesk-status/installed and	($service-status/service-present != 1) and ($vestate = $env-state/running)">
					<!-- Linux: VE is on , not under vzpp control (catch be prev when's)
								 try get pure psa password, store it in session.
								 show error if fail, if all ok - show login form, and password change form -->
					<xsl:variable name="plesk-password-detail-rtf">
						<xsl:call-template name="plesk:get-plesk-password"/>
					</xsl:variable>
					<xsl:variable name="plesk-password-detail" select="exsl:node-set($plesk-password-detail-rtf)"/>
					<xsl:choose>
						<xsl:when test="$plesk-password-detail/process/error">
							<!-- system error occured: no such programm, vzenv is down, other -->
							<xsl:variable name="plesk-detail" select="$plesk-password-detail/process/error/message"/>
							<xsl:message>Plesk manage error: can't get password for VE #<xsl:value-of
									select="$ve-eid"/>: <xsl:value-of select="$plesk-detail"/></xsl:message>
							<xsl:variable name="error">
								<sw:text>
									<xsl:with-param name="plesk-detail" select="$plesk-detail"
									/>
											An internal error occurred in Plesk.<br/> %{plesk-detail}
									</sw:text>
							</xsl:variable>
							<xsl:if test="sw:sesput('ve-error',$error)"/>
						</xsl:when>

						<xsl:otherwise>
							<!-- login to plesk with plesk password , plesk not controlled by vz -->
							<xsl:if test="$cr-plesk-login">
								<xsl:variable name="plesk-password-raw"
									select="sw:base64-decode($plesk-password-detail/process/output)"/>
								<xsl:if
									test="sw:sesputstr('plesk-passwd',sw:split($plesk-password-raw,'&#10;')[1])"/>
								<xsl:call-template name="psa-login">
									<xsl:with-param name="vzpp-plesk-present" select="$service-status/service-present"
									/>
								</xsl:call-template>
							</xsl:if>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>

				<xsl:when test="$vzve-plesk-status/installed and ($service-status/service-present = 1)">
					<!-- login to plesk , plesk controlled by vz -->
					<xsl:if test="$cr-plesk-login">
						<xsl:call-template name="psa-login">
							<xsl:with-param name="vzpp-plesk-present" select="$service-status/service-present"/>
						</xsl:call-template>
					</xsl:if>
				</xsl:when>

				<xsl:when test="not($platform-is-linux)">
					<!-- windows: plesk installed, ip present, vzenv run -->
					<xsl:call-template name="psa-login">
						<xsl:with-param name="vzpp-plesk-present" select="$service-status/service-present"/>
					</xsl:call-template>
				</xsl:when>

			</xsl:choose>
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="sw:sesget('ve-error')">
				<ui:popup-screen id="03.05.00.01.04" title="{sw:text('Plesk is unavailable')}">
					<ui:properties> </ui:properties>
					<ui:content>
						<ui:raw>
							<xsl:copy-of select="sw:sesget('ve-error')"/>
						</ui:raw>
					</ui:content>
				</ui:popup-screen>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="$login-result"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="psa-login">
		<xsl:param name="vzpp-plesk-present" select="0"/>
		<xsl:variable name="env-config"				select="env:get-env($ve-eid)/env"/>
		<xsl:variable name="platform"					select="env:env2platform($env-config)"/>
		<xsl:variable name="psa-port-offline"	select="redirect:load($env-config/parent_eid,'vzpp-plesk')/service/port"/>
		<xsl:variable name="psa-port-standalone"	select="sw:if(string($config/vzcpcon/defines/standalone-plesk-port) = '','8443',string($config/vzcpcon/defines/standalone-plesk-port))"/>
		<xsl:variable name="new-ticket" select="sw:new-pp-session($ve-eid, $super-user)"/>
		<xsl:variable name="psa-uri-rtf">
			<xsl:choose>
				<xsl:when test="$vzpp-plesk-present = 1">
					<url>
						<xsl:value-of select="'/vz/cp/panel/plesk/frameset'"/>
					</url>
					<port>
						<xsl:value-of select="$psa-port-offline"/>
					</port>
				</xsl:when>
				<xsl:otherwise>
					<!-- plesk present, but not controled -->
					<xsl:choose>
						<xsl:when test="$platform-is-linux">
							<url>
								<xsl:value-of select="'/login_up.php3'"/>
							</url>
							<port>
								<xsl:value-of select="$psa-port-standalone"/>
							</port>
						</xsl:when>
						<xsl:otherwise>
							<url>
								<xsl:value-of select="'/'"/>
							</url>
							<port>
								<xsl:value-of select="$psa-port-standalone"/>
							</port>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<!-- redirect parameters depend from platform and demo mode -->
		<xsl:variable name="psa-uri"	select="exsl:node-set($psa-uri-rtf)"/>
		<xsl:variable name="host"			select="sw:if($platform-is-linux, $env-config/virtual_config/address/ip[1], $env-config/virtual_config/hostname)"/>
		<!-- get plesk settings from vzenv -->
		<xsl:variable name="psa-setup" select="plesk:getPsaSetup()"/>

		<!-- plesk lang depend from mode and active_lang_id -->
		<xsl:variable name="plesk-lang-id" select="$psa-setup/admin/lang"/>
		<xsl:variable name="plesk-skin-id" select="$psa-setup/admin/skin"/>

		<!-- set lang for vzcp self -->
		<xsl:variable name="location"
			select="concat('https://',$host,':',$psa-uri/port,$psa-uri/url,'?LoginTicket=',$new-ticket,'&amp;psa_active_lang=',$plesk-lang-id,'&amp;psa_active_skin=',$plesk-skin-id)"/>

		<xsl:choose>
			<xsl:when test="$vzpp-plesk-present = 1">
				<ui:redirect location="{$location}"/>
			</xsl:when>
			<xsl:otherwise>
				<ui:redirect location="{$location}" type="javascript">
					<ui:arg name="login_name">
						<xsl:value-of select="'admin'"/>
					</ui:arg>
					<ui:arg name="passwd">
						<xsl:value-of select="sw:sesgetstr('plesk-passwd')"/>
					</ui:arg>
					<ui:arg name="locale">
						<xsl:value-of select="$plesk-lang-id"/>
					</ui:arg>
				</ui:redirect>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-offline.xsl"/>
	<sw:include href="/lib/vz/vzhn-redirects.xsl"/>
	<sw:include href="/lib/psa_auth.xsl"/>
	<sw:include href="/lib/plesk/core.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/progm.xsl"/>

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/cred.xsl"/>

</xsl:stylesheet>
