<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred plesk local"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:plesk	="http://www.swsoft.com/xsl/cp/plesk"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"
	xmlns:ve		="http://www.swsoft.com/xsl/cp/ve"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"
	xmlns:voc   ="http://www.swsoft.com/xsl/cp/voc"
	xmlns:vzenv	="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:proc	="http://www.swsoft.com/xsl/cp/proc"
>

	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/plesk/core.xsl"/>
	<sw:include href="/lib/vz/vzenv-qos.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>	

	<xsl:variable name="plesk-component-state-rtf">
		<xsl:for-each select="/packet/data/servicem/service">
			<service>
				<xsl:copy-of select="name|state"/>
			</service>
		</xsl:for-each>
	</xsl:variable>
	<xsl:variable name="plesk-component-state" select="exsl:node-set($plesk-component-state-rtf)"/>

	<xsl:variable name="psa_internal_error"	select="sw:html-unescape($request/http_request/get/parameter[name = 'psa_error']/value)"/>
	<xsl:variable name="psa_httpd_error"	select="sw:html-unescape($request/http_request/get/parameter[name = 'psa_httpd_error']/value)"/>
	<xsl:variable name="plesk-state" select="sw:sesget('plesk-state')"/>
	<xsl:variable name="eid" select="sw:ve-eid()"/>

	<!-- check for ve alerts -->
	<xsl:variable name="sysinfo-rtf">
		<xsl:call-template name="proc:sysinfo">
			<xsl:with-param name="eid" select="$eid"/>
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="sysinfo" select="exsl:node-set($sysinfo-rtf)"/>
	<xsl:variable name="total-alerts" select="vzenv:get-all-alerts($sysinfo)"/>
	
	<xsl:template name="local:show-new-diag">
		<xsl:param name="pleskctl-status"/>
		<xsl:param name="vzve-plesk-status"/>
		<xsl:variable name="vz-diag">
			<xsl:choose>
				<xsl:when test="$plesk-state = 'deny'">
					<sw:text>Plesk is not allowed</sw:text>
				</xsl:when>
				<xsl:when test="$vzve-plesk-status/not-installed">
					<sw:text>The service is not available now.</sw:text>
					<xsl:if test="cred:check-env('vzcp.env.manage.services_and_files',$eid)">
						<sw:text>
							Plesk is not installed.
						</sw:text>
					</xsl:if>
					<br/>
					<ui:i18n-link href="{$baseurl}/panel/plesk/install?path=reset" tip="03.00.00.03.05">
						<_>Click %{aopen}here%{aclose} to start the Plesk installation.</_>
					</ui:i18n-link>
				</xsl:when>
				<xsl:when test="$vzve-plesk-status/unknown">
					<sw:text>The service is not available now.</sw:text>
					<xsl:if test="cred:check-env('vzcp.env.manage.services_and_files',$eid)">
						<sw:text>
							Plesk cannot be detected.
						</sw:text>
					</xsl:if>
				</xsl:when>
				<xsl:when test="count($pleskctl-status/pleskctl/problem) &gt; 0">non-vz-diag</xsl:when>
				<xsl:when test="($psa_internal_error != '') or ($psa_httpd_error != '')">
					<sw:text>The service is not available now.</sw:text>
					<br/>
					<sw:text>Contact your provider for details.</sw:text>
					<br/>
					<xsl:if test="$psa_internal_error">
						<br/> Internal Plesk error occurred: <br/>
						<xsl:value-of disable-output-escaping="yes" select="$psa_internal_error"/>
					</xsl:if>
					<xsl:if test="$psa_httpd_error">
						<br/> Internal Plesk webserver error occurred: <br/>
						<xsl:value-of disable-output-escaping="yes" select="$psa_httpd_error"/>
					</xsl:if>
				</xsl:when>

        <xsl:otherwise>non-vz-diag</xsl:otherwise>
      </xsl:choose>
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="$vz-diag != 'non-vz-diag'">
				<ui:stop-sign>
					<xsl:copy-of select="$vz-diag"/>
				</ui:stop-sign>
				<xsl:call-template name="local:js-addon"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="local:pleskctl-diag">
					<xsl:with-param name="pleskctl-status" select="$pleskctl-status"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<xsl:template name="local:pleskctl-diag">
		<xsl:param name="pleskctl-status"/>
		<xsl:variable name="repair-mode" select="$request/http_request/post/parameter[name = 'doRepair']/value"/> 
		<xsl:variable name="result-pleskctl-rtf">
			<xsl:choose>
				<xsl:when test="$repair-mode != ''">
					<xsl:variable name="actions" select="$request/http_request/post/parameter[name = 'action']/value"/>
					<xsl:call-template name="plesk:pleskctl-repair">
						<xsl:with-param name="actions" select="$actions"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$pleskctl-status"/>
				</xsl:otherwise>
			</xsl:choose>	
		</xsl:variable>
		<xsl:variable name="result-pleskctl" select="exsl:node-set($result-pleskctl-rtf)"/>
		<ui:block mode="edit">
			<xsl:choose>
				<xsl:when test="$result-pleskctl/error">
					<ui:rows>
						<ui:row>
							<ui:cell>
								<b><sw:text>Problems found</sw:text></b>
							</ui:cell>
						</ui:row>
						<ui:row>
							<ui:cell>
								<sw:text>Failed to run the pleskctl utility</sw:text>
							</ui:cell>
						</ui:row>
						<ui:row>
							<ui:cell>
								<sw:text>Error code:</sw:text>
							</ui:cell>
							<ui:cell>
								<xsl:value-of select="$result-pleskctl/error/status"/>
							</ui:cell>
						</ui:row>
						<ui:row>
							<ui:cell>
								<sw:text>Error description:</sw:text>
							</ui:cell>
							<ui:cell>
								<xsl:value-of select="$result-pleskctl/error/detail"/>
							</ui:cell>
						</ui:row>
					</ui:rows>
				</xsl:when>
				<xsl:otherwise>	
					<xsl:if test="$repair-mode != ''">
						<!-- show repair result -->
						<xsl:for-each select="$result-pleskctl/pleskctl/action[log and status]">
							<ui:rows>
								<ui:row>
									<ui:cell>
										<b><sw:text>Repairing Plesk</sw:text></b>
									</ui:cell>
								</ui:row>
								<ui:row>
									<ui:cell>
										<xsl:value-of select="message"/>&#160;
										<xsl:call-template name="local:show-status-icon"/>
									</ui:cell>
								</ui:row>
								<ui:row>
									<ui:cell offset="1">
										<xsl:value-of select="log"/>
									</ui:cell>
								</ui:row>
							</ui:rows>
						</xsl:for-each>
					</xsl:if>
					<xsl:choose>
						<xsl:when test="count($result-pleskctl/pleskctl/problem) &gt; 0">
							<ui:rows>
								<ui:row>
									<ui:cell>
										<b><sw:text>Problems found:</sw:text></b>
									</ui:cell>
								</ui:row>
								<xsl:for-each select="$result-pleskctl/pleskctl/problem">
									<ui:row>
										<ui:cell offset="1">
											<xsl:value-of select="message"/>
										</ui:cell>
									</ui:row>
									<ui:row>
										<ui:cell offset="1">
											<b style="color:#444444"><sw:text>Solutions:</sw:text></b>
										</ui:cell>
									</ui:row>
									<xsl:for-each select="solutions/action">
										<ui:row>
											<xsl:variable name="cur-action-id" select="@id"/>
											<ui:cell-check offset="2" id="action_{$cur-action-id}"  name="action" value="{$cur-action-id}" close="false">
												<xsl:attribute name="checked">true</xsl:attribute>
											</ui:cell-check>
											<ui:cell  label="action_{$cur-action-id}" open="false">
												<xsl:value-of select="$result-pleskctl/pleskctl/action[@id = $cur-action-id]/message"/>
											</ui:cell>
										</ui:row>
									</xsl:for-each>
								</xsl:for-each>
							</ui:rows>
							<ui:buttons>
								<ui:button name="doRepair">
									<sw:text>Apply selected solutions</sw:text>
								</ui:button>
							</ui:buttons>
						</xsl:when>
						<xsl:when test="$result-pleskctl/pleskctl/action and  not($result-pleskctl/pleskctl/problem)">
							<ui:rows>
								<ui:row>
									<ui:cell>
										<sw:text>No problems found</sw:text>
									</ui:cell>
								</ui:row>
							</ui:rows>
						</xsl:when>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>						
		</ui:block>
		<xsl:call-template name="local:js-addon"/>
	</xsl:template>


	<xsl:template name="local:show-status-icon">
		<xsl:choose>
			<xsl:when test="status = 'ok'"><img src="/{$theme}/icons/alert_green.gif" height="16" width="16"/></xsl:when>
			<xsl:when test="status = 'warning'"><img src="/{$theme}/icons/alert_yellow.gif" height="16" width="16"/></xsl:when>
			<xsl:when test="status = 'error'"><img src="/{$theme}/icons/alert_red.gif" height="16" width="16"/></xsl:when>
			<!-- xsl:otherwise><img src="/{$theme}/icons/alert_grey.gif" height="16" width="16"/></xsl:otherwise -->
		</xsl:choose>
	</xsl:template>	


	<xsl:template name="local:show-old-diag">
		<xsl:param name="vzve-plesk-status"/>
		<ui:stop-sign>
			<xsl:choose>
				<xsl:when test="$plesk-state = 'deny'">
					<sw:text>Plesk is not allowed</sw:text>
				</xsl:when>
				<xsl:when test="$vzve-plesk-status/not-installed">
					<sw:text>The service is not available now.</sw:text>
					<xsl:if test="cred:check-env('vzcp.env.manage.services_and_files',$eid)">
						<sw:text>
							Plesk is not installed.
						</sw:text>
					</xsl:if>
					<br/>
					<ui:i18n-link href="{$baseurl}/panel/plesk/install?path=reset" tip="03.00.00.03.05">
						<_>Click %{aopen}here%{aclose} to start the Plesk installation.</_>
					</ui:i18n-link>
				</xsl:when>
				<xsl:when test="$vzve-plesk-status/unknown">
					<sw:text>The service is not available now.</sw:text>
					<xsl:if test="cred:check-env('vzcp.env.manage.services_and_files',$eid)">
						<sw:text>
							Plesk cannot be detected.
						</sw:text>
					</xsl:if>
				</xsl:when>

				<xsl:when test="$plesk-component-state/service/state != 1">
					<!-- one of more service is not running -->
					<xsl:for-each select="$plesk-component-state/service[state != 1][position() = last()]">
						<xsl:variable name="service-name" select="name"/>
						<sw:text>The service is not available now.</sw:text>
						<xsl:if test="cred:check-env('vzcp.env.manage.services_and_files',$eid)">
							<xsl:variable name="ve-platform" select="ve:ve2platform(env:get-env()/env)"/>
							<xsl:choose>
								<xsl:when test="vt:is-platform-linux($ve-platform)">
									<ui:i18n-link custom="{$service-name}"
										href="{$baseurl}/vzdir/infrman/envs/services/system/service?path=reset&amp;id={$service-name}"
										tip="03.02.01.07.05">
										<_>Please check the status of the %{aopen} "%{custom}" %{aclose} service.</_>
									</ui:i18n-link>
								</xsl:when>
								<xsl:when test="vt:is-platform-windows($ve-platform)">
									<ui:i18n-link custom="{$service-name}"
										href="{$baseurl}/vzdir/infrman/envs/services/system/services/index-win?path=reset&amp;filter_action=force_search&amp;filter_display-name={$service-name}"
										tip="03.02.01.07.07">
										<_>Please check the status of the %{aopen} "%{custom}" %{aclose} service.</_>
									</ui:i18n-link>
								 </xsl:when>
								</xsl:choose>
						</xsl:if>
					</xsl:for-each>
				</xsl:when>

				<xsl:when test="$plesk-state = 'demo'">
					<sw:text>Plesk is not accesssible in the demo mode.</sw:text>
				</xsl:when>
				<xsl:otherwise>
					<sw:text>The service is not available now.</sw:text>
					<br/>
					<sw:text>Contact your provider for details.</sw:text>
					<br/>
					<xsl:if test="$psa_internal_error">
						<br/> Internal Plesk error occurred: <br/>
						<xsl:value-of disable-output-escaping="yes" select="$psa_internal_error"/>
					</xsl:if>
					<xsl:if test="$psa_httpd_error">
						<br/> Internal Plesk webserver error occurred: <br/>
						<xsl:value-of disable-output-escaping="yes" select="$psa_httpd_error"/>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</ui:stop-sign>
	</xsl:template>


	<xsl:template mode="screen" match="/">
		<!-- refresh info about plesk each time -->
		<xsl:for-each select="packet/cookie/envm/env/virtual_config">

			<!-- update  veinfo  -->
			<xsl:value-of select="sw:sesput('hostname', string(hostname))"/>
			<xsl:value-of select="sw:sesput('templates', template)"/>
			<xsl:value-of select="sw:sesput('ip',ip)"/>
		</xsl:for-each>
		<xsl:choose>
			<xsl:when test="$request/http_request/get/parameter[name = 'context']/value = 'help'">
				<xsl:call-template name="local:popup-screen"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="local:not-popup-screen"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<xsl:template name="local:popup-screen">
		<ui:popup-screen id="03.05.00.03.08" title="{sw:text('Plesk diagnostics')}">
			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:no-uplevel/>
				<ui:width value="fixed"/>
				<ui:no-screenid/>
				<ui:no-help/>
			</ui:properties>
			<ui:content>
				<ui:stop-sign>
					<sw:text>
          No help for this page is available now.
        </sw:text>
				</ui:stop-sign>
				<xsl:call-template name="local:js-addon"/>
			</ui:content>
		</ui:popup-screen>
	</xsl:template>


	<xsl:template name="local:not-popup-screen">
		<!-- first of all - check that VE is running -->
		<xsl:variable name="oper-problem" select="voc:check-operation('plesk','','',$eid)"/>		
		<ui:screen id="03.05.00.03.08" title="{sw:text('Plesk diagnostics')}">
			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:no-uplevel/>
				<ui:width value="fixed"/>
			</ui:properties>
			<ui:content>
				<xsl:choose>
					<xsl:when test="$oper-problem!=''">
						<!-- problem with VE state/transition -->
						<ui:block>
							<ui:operation-problem>
								<xsl:copy-of select="$oper-problem"/>
								<ui:descr><sw:text>The service is not available now.</sw:text></ui:descr>
							</ui:operation-problem>
						</ui:block>
					</xsl:when>
					<xsl:when test="count($total-alerts/alerts/alert[(id != 'cpuunits') and (type &gt; 1)]) &gt; 0">
						<!-- handle qos alert here -->
						<ui:stop-sign>
							<sw:text>The service is not available now.</sw:text>
							<br/>
							<ui:i18n-link href="{$baseurl}/core/alerts">
							  <_>Some Container resources are overused. %{aopen}Click%{aclose} to see the details.</_>
							</ui:i18n-link>
						</ui:stop-sign>
					</xsl:when>					
					<xsl:otherwise>
						<!-- no problem with VE, try get internal plesk diagnostic --> 	
						<xsl:variable name="pleskctl-status-rtf">
							<xsl:call-template name="plesk:pleskctl-status"/>
						</xsl:variable>
						<xsl:variable name="pleskctl-status"		select="exsl:node-set($pleskctl-status-rtf)"/>
						<xsl:variable name="vzve-plesk-status"	select="plesk:detect-plesk(sw:ve-eid())"/>
						<xsl:choose>
							<xsl:when test="$pleskctl-status/error/file_not_found">
								<!-- no pleskctl found, old interface -->
								<xsl:call-template name="local:show-old-diag">
									<xsl:with-param name="vzve-plesk-status" select="$vzve-plesk-status"/>
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:call-template name="local:show-new-diag">
									<xsl:with-param name="pleskctl-status" select="$pleskctl-status"/>
									<xsl:with-param name="vzve-plesk-status" select="$vzve-plesk-status"/>
								</xsl:call-template>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</ui:content>
		</ui:screen>
	</xsl:template>


	<xsl:template name="local:js-addon">
    <ui:java-script>
      if (this.name == 'topFrame')
        this.location = '/vz/cp/panel/plesk/top';
      menu_item_no_change=1;
      function SetContext(){
      //placeholder
      }
      if (top.tips_dynamic) {
        top.tips_dynamic_key = '';
      }
    </ui:java-script>
	</xsl:template>


	<sw:include href="/lib/screen.xsl"/>

</xsl:stylesheet>
