<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
	xmlns:ve		="http://www.swsoft.com/xsl/cp/ve"
	xmlns:plesk	="http://www.swsoft.com/xsl/cp/plesk"
>

	<!-- check permissions to show this page -->
	<xsl:variable name="eid" select="sw:ve-eid()"/>
	<xsl:variable name="cr-plesk-panel"
		select="cred:check-env('vzcp.env.manage.services.plesk_control_panel',$eid)"/>
	<xsl:variable name="cr-plesk-password"
		select="cred:check-env('vzcp.env.manage.services.plesk_control_panel',$eid)"/>
	<xsl:param name="access-denied" select="not($cr-plesk-password)"/>

	<xsl:variable name="vzve-plesk-status" select="plesk:detect-plesk($eid)"/>
	<xsl:variable name="admin_pwd"
		select="$request/http_request/post/parameter[name = 'admin_pwd']/value"/>
	<xsl:variable name="admin_pwd_re"
		select="$request/http_request/post/parameter[name = 'admin_pwd_re']/value"/>

	<xsl:template name="psa-password">
		<ui:block mode="edit">
			<ui:rows title="{sw:text('Password')}">
				<ui:row>
					<ui:cell-label>
						<sw:text>
										New admin password
									</sw:text>
					</ui:cell-label>
					<ui:cell-input mode-password="true" id="admin_pwd" maxlength="64">
						<xsl:attribute name="value">
							<xsl:value-of select="$admin_pwd"/>
						</xsl:attribute>
					</ui:cell-input>
				</ui:row>
				<ui:row>
					<ui:cell-label>
						<sw:text>
										Retype the new admin password
									</sw:text>
					</ui:cell-label>
					<ui:cell-input mode-password="true" id="admin_pwd_re" maxlength="64">
						<xsl:attribute name="value">
							<xsl:value-of select="$admin_pwd_re"/>
						</xsl:attribute>
					</ui:cell-input>
				</ui:row>
			</ui:rows>
			<ui:buttons>
				<ui:button type="ok" name="_submit" tip="submit_plesk_pwd_change">
					<sw:text>Change</sw:text>
				</ui:button>
				<ui:button type="cancel" sandclock="false"
					tip="discard_pwd_change">
					<sw:text>Discard</sw:text>
				</ui:button>
			</ui:buttons>
		</ui:block>
	</xsl:template>

	<xsl:template mode="screen" match="/">
		<xsl:variable name="vestate" select="ve:context-state()"/>
		<ui:screen id="03.05.00.01.02" title="{sw:text('Change Plesk Admin Password')}"
			icon="change_plesk_password" bg="plesk">
			<ui:properties>
				<ui:width value="fixed"/>
				<ui:description width="full" mandatory="yes">
					<sw:text>
							You can change your Plesk admin password.
							<br/>
							The password should have 5 characters or more.
							<br/>
							Please do not choose passwords which are easy to guess for others.
						</sw:text>
				</ui:description>
			</ui:properties>

			<ui:content>

				<xsl:choose>
					<xsl:when test="$vzve-plesk-status/not-installed">
						<!-- plesk not present -->
						<ui:block>
							<ui:operation-problem>
								<ui:descr>
									<sw:text>You have no Plesk installed into your Container.</sw:text>
								</ui:descr>
							</ui:operation-problem>
						</ui:block>
					</xsl:when>
					<xsl:when test="$vzve-plesk-status/installed and ($vestate != $env-state/running)">
						<!-- vzenv not controlled by VZPP and VE is down -->
						<xsl:variable name="oper-problem" select="voc:check-operation('plesk')"/>
						<ui:block>
							<ui:operation-problem>
								<xsl:copy-of select="$oper-problem"/>
								<ui:descr>
									<sw:text>Unable to manage Plesk</sw:text>
								</ui:descr>
							</ui:operation-problem>
						</ui:block>
					</xsl:when>
					<xsl:when test="$vzve-plesk-status/installed and ($vestate = $env-state/running)">
						<xsl:call-template name="psa-password"/>
					</xsl:when>
				</xsl:choose>

			</ui:content>
		</ui:screen>
	</xsl:template>


	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/plesk/core.xsl"/>
	
</xsl:stylesheet>
